@@ -40,7 +40,7 @@ class KRITAUI_EXPORT KisWetPaletteWidget
      : public TQWidget,
        public KisCanvasObserver
 {
-     Q_OBJECT
+     TQ_OBJECT
   
     typedef TQWidget super;
 
