@@ -27,7 +27,7 @@ class KisView;
 
 class SelectOpaque : public KParts::Plugin
 {
-        Q_OBJECT
+        TQ_OBJECT
   
     public:
         SelectOpaque(TQObject *parent, const char *name, const TQStringList &);
