@@ -27,7 +27,7 @@ class TDEAboutData;
 
 class ExampleFactory : public KoFactory
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ExampleFactory( TQObject* parent = 0, const char* name = 0 );
