@@ -45,7 +45,7 @@ class VTransformCmd;
 
 class SvgExport : public KoFilter, private VVisitor
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
