@@ -33,7 +33,7 @@ class VLayer;
 
 class XcfExport : public KoFilter, private VVisitor
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
