@@ -51,7 +51,7 @@ class KWordTextHandler;
 
 class Document : public TQObject, public wvWare::SubDocumentHandler
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Document( const std::string& fileName, TQDomDocument& mainDocument, TQDomDocument &documentInfo, TQDomElement& framesetsElement, KoFilterChain* chain );
