@@ -531,7 +531,7 @@ TQString KWordTextHandler::getFont(unsigned fc) const
     TQFontInfo info( xFont );
 
 #ifdef FONT_DEBUG
-    kdDebug(30513) << "    QT-FONT: " << info.family() << endl;
+    kdDebug(30513) << "    TQt-FONT: " << info.family() << endl;
 #endif
 
     return info.family();
@@ -659,7 +659,7 @@ void KWordTextHandler::writeLayout( TQDomElement& parentElement, const wvWare::P
             // which kword doesn't support. We map it to 0 with a clever '%4' :)
             tabElement.setAttribute( "type", td.tbd.jc % 4 );
             int filling = 0;
-            double width = 0.5; // default kword value, see koparaglayout.cc
+            double width = 0.5; // default kword value, see koparaglayout.cpp
             switch ( td.tbd.tlc ) {
             case 1: // dots
             case 2: // hyphenated
