@@ -27,7 +27,7 @@
 
 class XSLTImportDia : public XSLTDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 	TQString _fileIn;
