@@ -44,7 +44,7 @@ class VCommandHistory;
 
 class KARBONCOMMON_EXPORT KarbonPart : public KoDocument
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KarbonPart( TQWidget* parentWidget = 0L, const char* widgetName = 0L,
