@@ -57,7 +57,7 @@ class KChartParameterPolarConfigPage;
 
 class KChartConfigDialog : public TQTabDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
