@@ -55,10 +55,6 @@
 //
 
 
-#ifndef TQT_H
-#include "tqabstractlayout.h"
-#endif // TQT_H
-
 #ifndef TQT_NO_LAYOUT
 struct QLayoutStruct
 {
