@@ -78,7 +78,7 @@ KexiDBComboBox::KexiDBComboBox(TQWidget *parent, const char *name, bool designMo
  , d(new Private())
 {
 	setMouseTracking(true);
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 	installEventFilter(this);
 	d->designMode = designMode;
 	d->paintedCombo = new KComboBox(this);
@@ -161,7 +161,7 @@ void KexiDBComboBox::paintEvent( TQPaintEvent * )
 				p.fillRect( editorGeometry, cg.brush( TQColorGroup::Highlight ) );
 			TQRect r( TQStyle::visualRect( style().subRect( TQStyle::SR_ComboBoxFocusRect, d->paintedCombo ), this ) );
 			r = TQRect(r.left()-1, r.top()-1, r.width()+2, r.height()+2); //enlare by 1 pixel each side to avoid covering by the subwidget
-			style().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, 
+			style().drawPrimitive( TQStyle::PE_FocusRect, &p, 
 				r, cg, flags | TQStyle::Style_FocusAtBorder, TQStyleOption(cg.highlight()));
 		}
 		//todo
@@ -186,7 +186,6 @@ void KexiDBComboBox::createEditor()
 		m_subwidget->setGeometry( editorGeometry() );
 		if (!d->isEditable) {
 			m_subwidget->setCursor(TQCursor(TQt::ArrowCursor)); // widgets like listedit have IbeamCursor, we don't want that
-//! @todo TQt4: set transparent background, for now we're setting button color
 			TQPalette subwidgetPalette( m_subwidget->palette() );
 			subwidgetPalette.setColor(TQPalette::Active, TQColorGroup::Base, 
 				subwidgetPalette.color(TQPalette::Active, TQColorGroup::Button));
@@ -197,7 +196,7 @@ void KexiDBComboBox::createEditor()
 				d->subWidgetsWithDisabledEvents = new TQPtrDict<char>();
 			d->subWidgetsWithDisabledEvents->insert(m_subwidget, (char*)1);
 			m_subwidget->installEventFilter(this);
-			TQObjectList *l = m_subwidget->queryList( TQWIDGET_OBJECT_NAME_STRING );
+			TQObjectList *l = m_subwidget->queryList( "TQWidget" );
 			for ( TQObjectListIt it( *l ); it.current(); ++it ) {
 				d->subWidgetsWithDisabledEvents->insert(it.current(), (char*)1);
 				it.current()->installEventFilter(this);
@@ -240,7 +239,7 @@ TQRect KexiDBComboBox::buttonGeometry() const
 
 bool KexiDBComboBox::handleMousePressEvent(TQMouseEvent *e)
 {
-	if ( e->button() != Qt::LeftButton || d->designMode )
+	if ( e->button() != TQt::LeftButton || d->designMode )
 		return true;
 /*todo	if ( m_discardNextMousePress ) {
 		d->discardNextMousePress = FALSE;
@@ -271,9 +270,9 @@ bool KexiDBComboBox::handleMousePressEvent(TQMouseEvent *e)
 bool KexiDBComboBox::handleKeyPressEvent(TQKeyEvent *ke)
 {
 	const int k = ke->key();
-	const bool dropDown = (ke->state() == Qt::NoButton && ((k==TQt::Key_F2 && !d->isEditable) || k==TQt::Key_F4))
+	const bool dropDown = (ke->state() == TQt::NoButton && ((k==TQt::Key_F2 && !d->isEditable) || k==TQt::Key_F4))
 		|| (ke->state() == TQt::AltButton && k==TQt::Key_Down);
-	const bool escPressed = ke->state() == Qt::NoButton && k==TQt::Key_Escape;
+	const bool escPressed = ke->state() == TQt::NoButton && k==TQt::Key_Escape;
 	const bool popupVisible =  popup() && popup()->isVisible();
 	if ((dropDown || escPressed) && popupVisible) {
 		popup()->hide();
@@ -303,12 +302,12 @@ bool KexiDBComboBox::keyPressed(TQKeyEvent *ke)
 
 	const int k = ke->key();
 	const bool popupVisible =  popup() && popup()->isVisible();
-	const bool escPressed = ke->state() == Qt::NoButton && k==TQt::Key_Escape;
+	const bool escPressed = ke->state() == TQt::NoButton && k==TQt::Key_Escape;
 	if (escPressed && popupVisible) {
 		popup()->hide();
 		return true;
 	}
-	if (ke->state() == Qt::NoButton && (k==TQt::Key_PageDown || k==TQt::Key_PageUp) && popupVisible)
+	if (ke->state() == TQt::NoButton && (k==TQt::Key_PageDown || k==TQt::Key_PageUp) && popupVisible)
 		return true;
 	return false;
 }
@@ -318,7 +317,7 @@ void KexiDBComboBox::mousePressEvent( TQMouseEvent *e )
 	if (handleMousePressEvent(e))
 		return;
 
-//	TQTimer::singleShot( 200, this, TQT_SLOT(internalClickTimeout()));
+//	TQTimer::singleShot( 200, this, TQ_SLOT(internalClickTimeout()));
 //	d->shortClick = TRUE;
 //  }
 	KexiDBAutoField::mousePressEvent( e );
@@ -331,7 +330,7 @@ void KexiDBComboBox::mouseDoubleClickEvent( TQMouseEvent *e )
 
 bool KexiDBComboBox::eventFilter( TQObject *o, TQEvent *e )
 {
-	if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(this)) {
+	if (o==this) {
 		if (e->type()==TQEvent::Resize) {
 			d->paintedCombo->resize(size());
 			if (m_subwidget)
@@ -339,7 +338,7 @@ bool KexiDBComboBox::eventFilter( TQObject *o, TQEvent *e )
 		}
 		else if (e->type()==TQEvent::Enter) {
 			if (!d->isEditable 
-				|| /*over button if editable combo*/buttonGeometry().contains( TQT_TQMOUSEEVENT(e)->pos() )) 
+				|| /*over button if editable combo*/buttonGeometry().contains( static_cast<TQMouseEvent*>(e)->pos() )) 
 			{
 				d->mouseOver = true;
 				update();
@@ -347,7 +346,7 @@ bool KexiDBComboBox::eventFilter( TQObject *o, TQEvent *e )
 		}
 		else if (e->type()==TQEvent::MouseMove) {
 			if (d->isEditable) {
-				const bool overButton = buttonGeometry().contains( TQT_TQMOUSEEVENT(e)->pos() );
+				const bool overButton = buttonGeometry().contains( static_cast<TQMouseEvent*>(e)->pos() );
 				if (overButton != d->mouseOver) {
 					d->mouseOver = overButton;
 					update();
@@ -360,7 +359,7 @@ bool KexiDBComboBox::eventFilter( TQObject *o, TQEvent *e )
 		}
 		else if (e->type()==TQEvent::KeyPress) {
 			// handle F2/F4
-			if (handleKeyPressEvent(TQT_TQKEYEVENT(e)))
+			if (handleKeyPressEvent(static_cast<TQKeyEvent*>(e)))
 				return true;
 		}
 		else if (e->type()==TQEvent::FocusOut) {
@@ -373,11 +372,11 @@ bool KexiDBComboBox::eventFilter( TQObject *o, TQEvent *e )
 	else if (!d->isEditable && d->subWidgetsWithDisabledEvents && d->subWidgetsWithDisabledEvents->find(o)) {
 		if (e->type()==TQEvent::MouseButtonPress) {
 			// clicking the subwidget should mean the same as clicking the combo box (i.e. show the popup)
-			if (handleMousePressEvent(TQT_TQMOUSEEVENT(e)))
+			if (handleMousePressEvent(static_cast<TQMouseEvent*>(e)))
 				return true;
 		}
 		else if (e->type()==TQEvent::KeyPress) {
-			if (handleKeyPressEvent(TQT_TQKEYEVENT(e)))
+			if (handleKeyPressEvent(static_cast<TQKeyEvent*>(e)))
 				return true;
 		}
 		return e->type()!=TQEvent::Paint;
@@ -509,7 +508,7 @@ TQSize KexiDBComboBox::sizeHint() const
 
 	const int maxWidth = 7 * fontMetrics().width(TQChar('x')) + 18;
 	const int maxHeight = TQMAX( fontMetrics().lineSpacing(), 14 ) + 2;
-	d->sizeHint = (style().tqsizeFromContents(TQStyle::CT_ComboBox, d->paintedCombo,
+	d->sizeHint = (style().sizeFromContents(TQStyle::CT_ComboBox, d->paintedCombo,
 		TQSize(maxWidth, maxHeight)).expandedTo(TQApplication::globalStrut()));
 
 	return d->sizeHint;
