@@ -223,11 +223,11 @@ bool KexiCSVExport::exportData(KexiDB::TableOrQuerySchema& tableOrQuery,
 					APPEND( cursor->value(real_i).toString() );
 			}
 			else if (isDateTime[real_i]) { //avoid "T" in ISO DateTime
-				APPEND( cursor->value(real_i).toDateTime().date().toString(Qt::ISODate)+" "
-					+ cursor->value(real_i).toDateTime().time().toString(Qt::ISODate) );
+				APPEND( cursor->value(real_i).toDateTime().date().toString(TQt::ISODate)+" "
+					+ cursor->value(real_i).toDateTime().time().toString(TQt::ISODate) );
 			}
 			else if (isTime[real_i]) { //time is temporarily stored as null date + time...
-				APPEND( cursor->value(real_i).toTime().toString(Qt::ISODate) );
+				APPEND( cursor->value(real_i).toTime().toString(TQt::ISODate) );
 			}
 			else if (isBLOB[real_i]) { //BLOB is escaped in a special way
 				if (hasTextQuote)
