@@ -235,7 +235,7 @@ KexiCSVImportDialog::KexiCSVImportDialog( Mode mode, KexiMainWindow* mainWin,
 
 	m_primaryKeyField = new TQCheckBox( i18n( "Primary key" ), page, "m_primaryKeyField" );
 	glyr->addWidget( m_primaryKeyField, 2, 1 );
-	connect(m_primaryKeyField, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotPrimaryKeyFieldToggled(bool)));
+	connect(m_primaryKeyField, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotPrimaryKeyFieldToggled(bool)));
 
 	m_comboQuote = new KexiCSVTextQuoteComboBox( page );
 	glyr->addWidget( m_comboQuote, 1, 2 );
@@ -364,26 +364,26 @@ if ( m_mode == Clipboard )
 
 	m_table->setSelectionMode(TQTable::NoSelection);
 
-	connect(m_formatCombo, TQT_SIGNAL(activated(int)),
-	  this, TQT_SLOT(formatChanged(int)));
-	connect(m_delimiterWidget, TQT_SIGNAL(delimiterChanged(const TQString&)),
-	  this, TQT_SLOT(delimiterChanged(const TQString&)));
-	connect(m_startAtLineSpinBox, TQT_SIGNAL(valueChanged ( int )),
-	  this, TQT_SLOT(startlineSelected(int)));
-	connect(m_comboQuote, TQT_SIGNAL(activated(int)),
-	  this, TQT_SLOT(textquoteSelected(int)));
-	connect(m_table, TQT_SIGNAL(currentChanged(int, int)),
-	  this, TQT_SLOT(currentCellChanged(int, int)));
-	connect(m_table, TQT_SIGNAL(valueChanged(int,int)),
-	  this, TQT_SLOT(cellValueChanged(int,int)));
-	connect(m_ignoreDuplicates, TQT_SIGNAL(stateChanged(int)),
-	  this, TQT_SLOT(ignoreDuplicatesChanged(int)));
-	connect(m_1stRowForFieldNames, TQT_SIGNAL(stateChanged(int)),
-	  this, TQT_SLOT(slot1stRowForFieldNamesChanged(int)));
+	connect(m_formatCombo, TQ_SIGNAL(activated(int)),
+	  this, TQ_SLOT(formatChanged(int)));
+	connect(m_delimiterWidget, TQ_SIGNAL(delimiterChanged(const TQString&)),
+	  this, TQ_SLOT(delimiterChanged(const TQString&)));
+	connect(m_startAtLineSpinBox, TQ_SIGNAL(valueChanged ( int )),
+	  this, TQ_SLOT(startlineSelected(int)));
+	connect(m_comboQuote, TQ_SIGNAL(activated(int)),
+	  this, TQ_SLOT(textquoteSelected(int)));
+	connect(m_table, TQ_SIGNAL(currentChanged(int, int)),
+	  this, TQ_SLOT(currentCellChanged(int, int)));
+	connect(m_table, TQ_SIGNAL(valueChanged(int,int)),
+	  this, TQ_SLOT(cellValueChanged(int,int)));
+	connect(m_ignoreDuplicates, TQ_SIGNAL(stateChanged(int)),
+	  this, TQ_SLOT(ignoreDuplicatesChanged(int)));
+	connect(m_1stRowForFieldNames, TQ_SIGNAL(stateChanged(int)),
+	  this, TQ_SLOT(slot1stRowForFieldNamesChanged(int)));
 
-	connect(this, TQT_SIGNAL(user1Clicked()), this, TQT_SLOT(optionsButtonClicked()));
+	connect(this, TQ_SIGNAL(user1Clicked()), this, TQ_SLOT(optionsButtonClicked()));
 
-	installRecursiveEventFilter(TQT_TQOBJECT(this), TQT_TQOBJECT(this));
+	installRecursiveEventFilter(this, this);
 
 	initLater();
 }
@@ -406,7 +406,7 @@ void KexiCSVImportDialog::initLater()
 	if (m_dialogCancelled) {
 //		m_loadingProgressDlg->hide();
 	//	m_loadingProgressDlg->close();
-		TQTimer::singleShot(0, this, TQT_SLOT(reject()));
+		TQTimer::singleShot(0, this, TQ_SLOT(reject()));
 		return;
 	}
 
@@ -1078,7 +1078,7 @@ bool KexiCSVImportDialog::parseDate(const TQString& text, TQDate& date)
 
 bool KexiCSVImportDialog::parseTime(const TQString& text, TQTime& time)
 {
-	time = TQTime::fromString(text, Qt::ISODate); //same as m_timeRegExp1
+	time = TQTime::fromString(text, TQt::ISODate); //same as m_timeRegExp1
 	if (time.isValid())
 		return true;
 	if (m_timeRegExp2.exactMatch(text)) { //hh:mm:ss
@@ -1270,7 +1270,7 @@ void KexiCSVImportDialog::textquoteSelected(int)
 void KexiCSVImportDialog::fillTableLater()
 {
 	m_table->setNumRows( 0 );
-	TQTimer::singleShot(10, this, TQT_SLOT(fillTable()));
+	TQTimer::singleShot(10, this, TQ_SLOT(fillTable()));
 }
 
 void KexiCSVImportDialog::startlineSelected(int startline)
@@ -1630,7 +1630,7 @@ bool KexiCSVImportDialog::eventFilter ( TQObject * watched, TQEvent * e )
 		return true;
 
 	if (watched == m_startAtLineSpinBox && t==TQEvent::KeyPress) {
-		TQKeyEvent *ke = TQT_TQKEYEVENT(e);
+		TQKeyEvent *ke = static_cast<TQKeyEvent*>(e);
 		if (ke->key()==TQt::Key_Enter || ke->key()==TQt::Key_Return) {
 			m_table->setFocus();
 			return true;
