@@ -10,7 +10,7 @@ class TDEAboutData;
 
 class KFormulaFactory : public KoFactory
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KFormulaFactory( TQObject* parent = 0, const char* name = 0 );
