@@ -108,8 +108,8 @@ KivioIconView::KivioIconView( bool _readWrite,TQWidget *parent, const char *name
   setAcceptDrops(false);
   viewport()->setAcceptDrops(false);
   if(isReadWrite) {
-    connect(this, TQT_SIGNAL(doubleClicked(TQIconViewItem*)), this, TQT_SLOT(slotDoubleClicked(TQIconViewItem*)));
-    connect(this, TQT_SIGNAL(clicked(TQIconViewItem*)), this, TQT_SLOT(slotClicked(TQIconViewItem*)));
+    connect(this, TQ_SIGNAL(doubleClicked(TQIconViewItem*)), this, TQ_SLOT(slotDoubleClicked(TQIconViewItem*)));
+    connect(this, TQ_SIGNAL(clicked(TQIconViewItem*)), this, TQ_SLOT(slotClicked(TQIconViewItem*)));
   }
 }
 
