@@ -172,9 +172,9 @@ KivioView::KivioView( TQWidget *_parent, const char *_name, KivioDoc* doc )
   // Handle progress information from the doc
   m_statusBarProgress = 0;
 
-  connect(m_pDoc, TQT_SIGNAL(initProgress()), TQT_TQOBJECT(this), TQT_SLOT(initStatusBarProgress()));
-  connect(m_pDoc, TQT_SIGNAL(progress(int)), TQT_TQOBJECT(this), TQT_SLOT(setStatusBarProgress(int)));
-  connect(m_pDoc, TQT_SIGNAL(endProgress()), TQT_TQOBJECT(this), TQT_SLOT(removeStatusBarProgress()));
+  connect(m_pDoc, TQ_SIGNAL(initProgress()), this, TQ_SLOT(initStatusBarProgress()));
+  connect(m_pDoc, TQ_SIGNAL(progress(int)), this, TQ_SLOT(setStatusBarProgress(int)));
+  connect(m_pDoc, TQ_SIGNAL(endProgress()), this, TQ_SLOT(removeStatusBarProgress()));
 
   bool isModified = doc->isModified();
   m_pStencilBarDockManager = new StencilBarDockManager(this);
@@ -192,17 +192,17 @@ KivioView::KivioView( TQWidget *_parent, const char *_name, KivioDoc* doc )
   // Tab Bar
   m_pTabBar = new KoTabBar(tabSplit);
   connect( m_pTabBar,
-           TQT_SIGNAL(tabChanged(const TQString&)),
-           TQT_SLOT( changePage(const TQString&)));
-  connect( m_pTabBar, TQT_SIGNAL( doubleClicked() ), TQT_SLOT( renamePage() ) );
-  connect( m_pTabBar, TQT_SIGNAL( contextMenu( const TQPoint& ) ),
-      TQT_SLOT( popupTabBarMenu( const TQPoint& ) ) );
-  connect(m_pTabBar, TQT_SIGNAL(tabMoved(unsigned, unsigned)), TQT_TQOBJECT(this), TQT_SLOT(moveTab(unsigned, unsigned)));
+           TQ_SIGNAL(tabChanged(const TQString&)),
+           TQ_SLOT( changePage(const TQString&)));
+  connect( m_pTabBar, TQ_SIGNAL( doubleClicked() ), TQ_SLOT( renamePage() ) );
+  connect( m_pTabBar, TQ_SIGNAL( contextMenu( const TQPoint& ) ),
+      TQ_SLOT( popupTabBarMenu( const TQPoint& ) ) );
+  connect(m_pTabBar, TQ_SIGNAL(tabMoved(unsigned, unsigned)), this, TQ_SLOT(moveTab(unsigned, unsigned)));
   m_pTabBar->setReverseLayout( TQApplication::reverseLayout() );
 
   // Scroll Bar
-  m_vertScrollBar = new TQScrollBar(Qt::Vertical,pRightSide);
-  m_horzScrollBar = new TQScrollBar(Qt::Horizontal,tabSplit);
+  m_vertScrollBar = new TQScrollBar(TQt::Vertical,pRightSide);
+  m_horzScrollBar = new TQScrollBar(TQt::Horizontal,tabSplit);
 
   TQValueList<int> sizes;
   sizes << tabSplit->width() / 2 << tabSplit->width() / 2;
@@ -215,35 +215,35 @@ KivioView::KivioView( TQWidget *_parent, const char *_name, KivioDoc* doc )
   m_pCanvas = new KivioCanvas(canvasBase,this,doc,m_vertScrollBar,m_horzScrollBar);
   canvasBase->addWidget(m_pCanvas,0);
   canvasBase->raiseWidget(m_pCanvas);
-  m_pCanvas->setFocusPolicy(TQ_StrongFocus);
+  m_pCanvas->setFocusPolicy(TQWidget::StrongFocus);
 
   // Rulers
-  vRuler = new KoRuler(pRightSide, m_pCanvas, Qt::Vertical, Kivio::Config::defaultPageLayout(),
+  vRuler = new KoRuler(pRightSide, m_pCanvas, TQt::Vertical, Kivio::Config::defaultPageLayout(),
     KoRuler::F_HELPLINES, m_pDoc->unit());
   vRuler->showMousePos(true);
   vRuler->setZoom(zoomHandler()->zoomedResolutionY());
-  hRuler = new KoRuler(pRightSide, m_pCanvas, Qt::Horizontal, Kivio::Config::defaultPageLayout(),
+  hRuler = new KoRuler(pRightSide, m_pCanvas, TQt::Horizontal, Kivio::Config::defaultPageLayout(),
     KoRuler::F_HELPLINES, m_pDoc->unit());
   hRuler->showMousePos(true);
   hRuler->setZoom(zoomHandler()->zoomedResolutionX());
-  connect(m_vertScrollBar, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(setRulerVOffset(int)));
-  connect(m_horzScrollBar, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(setRulerHOffset(int)));
-  connect(vRuler, TQT_SIGNAL(unitChanged(KoUnit::Unit)), TQT_SLOT(rulerChangedUnit(KoUnit::Unit)));
-  connect(hRuler, TQT_SIGNAL(unitChanged(KoUnit::Unit)), TQT_SLOT(rulerChangedUnit(KoUnit::Unit)));
-  connect(vRuler, TQT_SIGNAL(doubleClicked()), TQT_SLOT(paperLayoutDlg()));
-  connect(hRuler, TQT_SIGNAL(doubleClicked()), TQT_SLOT(paperLayoutDlg()));
-  connect(m_pDoc, TQT_SIGNAL(unitChanged(KoUnit::Unit)), TQT_SLOT(setRulerUnit(KoUnit::Unit)));
-  connect(m_pCanvas, TQT_SIGNAL(visibleAreaChanged()), TQT_SLOT(updateRulers()));
+  connect(m_vertScrollBar, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(setRulerVOffset(int)));
+  connect(m_horzScrollBar, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(setRulerHOffset(int)));
+  connect(vRuler, TQ_SIGNAL(unitChanged(KoUnit::Unit)), TQ_SLOT(rulerChangedUnit(KoUnit::Unit)));
+  connect(hRuler, TQ_SIGNAL(unitChanged(KoUnit::Unit)), TQ_SLOT(rulerChangedUnit(KoUnit::Unit)));
+  connect(vRuler, TQ_SIGNAL(doubleClicked()), TQ_SLOT(paperLayoutDlg()));
+  connect(hRuler, TQ_SIGNAL(doubleClicked()), TQ_SLOT(paperLayoutDlg()));
+  connect(m_pDoc, TQ_SIGNAL(unitChanged(KoUnit::Unit)), TQ_SLOT(setRulerUnit(KoUnit::Unit)));
+  connect(m_pCanvas, TQ_SIGNAL(visibleAreaChanged()), TQ_SLOT(updateRulers()));
 
-  connect(vRuler, TQT_SIGNAL(addGuide(const TQPoint&, bool, int)),
-          &(m_pCanvas->guideLines()), TQT_SLOT(addGuide(const TQPoint&, bool, int)));
-  connect(vRuler, TQT_SIGNAL(moveGuide(const TQPoint&, bool, int)),
-          &(m_pCanvas->guideLines()), TQT_SLOT(moveGuide(const TQPoint&, bool, int)));
-  connect(hRuler, TQT_SIGNAL(addGuide(const TQPoint&, bool, int)),
-          &(m_pCanvas->guideLines()), TQT_SLOT(addGuide(const TQPoint&, bool, int)));
-  connect(hRuler, TQT_SIGNAL(moveGuide(const TQPoint&, bool, int)),
-          &(m_pCanvas->guideLines()), TQT_SLOT(moveGuide(const TQPoint&, bool, int)));
-  connect(&(m_pCanvas->guideLines()), TQT_SIGNAL(guideLinesChanged(KoView*)), m_pDoc, TQT_SLOT(updateGuideLines(KoView*)));
+  connect(vRuler, TQ_SIGNAL(addGuide(const TQPoint&, bool, int)),
+          &(m_pCanvas->guideLines()), TQ_SLOT(addGuide(const TQPoint&, bool, int)));
+  connect(vRuler, TQ_SIGNAL(moveGuide(const TQPoint&, bool, int)),
+          &(m_pCanvas->guideLines()), TQ_SLOT(moveGuide(const TQPoint&, bool, int)));
+  connect(hRuler, TQ_SIGNAL(addGuide(const TQPoint&, bool, int)),
+          &(m_pCanvas->guideLines()), TQ_SLOT(addGuide(const TQPoint&, bool, int)));
+  connect(hRuler, TQ_SIGNAL(moveGuide(const TQPoint&, bool, int)),
+          &(m_pCanvas->guideLines()), TQ_SLOT(moveGuide(const TQPoint&, bool, int)));
+  connect(&(m_pCanvas->guideLines()), TQ_SIGNAL(guideLinesChanged(KoView*)), m_pDoc, TQ_SLOT(updateGuideLines(KoView*)));
 
   TQGridLayout* layout = new TQGridLayout(pRightSide);
   layout->addWidget(hRuler, 0, 1);
@@ -254,11 +254,11 @@ KivioView::KivioView( TQWidget *_parent, const char *_name, KivioDoc* doc )
   layout->setRowStretch(1, 10);
   layout->setColStretch(1, 10);
 
-  TQWidget::setFocusPolicy( TQ_StrongFocus );
+  TQWidget::setFocusPolicy( TQWidget::StrongFocus );
   setFocusProxy( m_pCanvas );
 
-  connect( TQT_TQOBJECT(this), TQT_SIGNAL( invalidated() ), m_pCanvas, TQT_SLOT( update() ) );
-  connect( TQT_TQOBJECT(this), TQT_SIGNAL( regionInvalidated( const TQRegion&, bool ) ), m_pCanvas, TQT_SLOT( repaint( const TQRegion&, bool ) ) );
+  connect( this, TQ_SIGNAL( invalidated() ), m_pCanvas, TQ_SLOT( update() ) );
+  connect( this, TQ_SIGNAL( regionInvalidated( const TQRegion&, bool ) ), m_pCanvas, TQ_SLOT( repaint( const TQRegion&, bool ) ) );
 
   setInstance(KivioFactory::global());
   if ( !m_pDoc->isReadWrite() )
@@ -286,15 +286,15 @@ KivioView::KivioView( TQWidget *_parent, const char *_name, KivioDoc* doc )
   setActivePage(m_pDoc->map()->firstPage());
 
 
-  connect( m_pDoc, TQT_SIGNAL( sig_selectionChanged() ), TQT_SLOT( updateToolBars() ) );
-  connect( m_pDoc, TQT_SIGNAL( sig_addPage(KivioPage*) ), TQT_SLOT( addPage(KivioPage*) ) );
-  connect( m_pDoc, TQT_SIGNAL( sig_addSpawnerSet(KivioStencilSpawnerSet*) ), TQT_SLOT(addSpawnerToStackBar(KivioStencilSpawnerSet*)) );
-  connect( m_pDoc, TQT_SIGNAL( sig_updateView(KivioPage*) ), TQT_SLOT(slotUpdateView(KivioPage*)) );
-  connect( m_pDoc, TQT_SIGNAL( sig_pageNameChanged(KivioPage*,const TQString&)), TQT_SLOT(slotPageRenamed(KivioPage*,const TQString&)) );
+  connect( m_pDoc, TQ_SIGNAL( sig_selectionChanged() ), TQ_SLOT( updateToolBars() ) );
+  connect( m_pDoc, TQ_SIGNAL( sig_addPage(KivioPage*) ), TQ_SLOT( addPage(KivioPage*) ) );
+  connect( m_pDoc, TQ_SIGNAL( sig_addSpawnerSet(KivioStencilSpawnerSet*) ), TQ_SLOT(addSpawnerToStackBar(KivioStencilSpawnerSet*)) );
+  connect( m_pDoc, TQ_SIGNAL( sig_updateView(KivioPage*) ), TQ_SLOT(slotUpdateView(KivioPage*)) );
+  connect( m_pDoc, TQ_SIGNAL( sig_pageNameChanged(KivioPage*,const TQString&)), TQ_SLOT(slotPageRenamed(KivioPage*,const TQString&)) );
 
-  connect( m_pDoc, TQT_SIGNAL( sig_updateGrid()),TQT_SLOT(slotUpdateGrid()));
+  connect( m_pDoc, TQ_SIGNAL( sig_updateGrid()),TQ_SLOT(slotUpdateGrid()));
 
-  connect(m_pDoc, TQT_SIGNAL(loadingFinished()), TQT_TQOBJECT(this), TQT_SLOT(loadingFinished()));
+  connect(m_pDoc, TQ_SIGNAL(loadingFinished()), this, TQ_SLOT(loadingFinished()));
 
   initActions();
 
@@ -341,11 +341,11 @@ void KivioView::createGeometryDock()
   m_pStencilGeometryPanel->setUnit(m_pDoc->unit());
   paletteManager()->addWidget(m_pStencilGeometryPanel, "stencilgeometrypanel", "geometrydocker");
 
-  connect( m_pStencilGeometryPanel, TQT_SIGNAL(positionChanged(double, double)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeStencilPosition(double, double)) );
-  connect( m_pStencilGeometryPanel, TQT_SIGNAL(sizeChanged(double, double)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeStencilSize(double, double)) );
-//   connect(m_pStencilGeometryPanel, TQT_SIGNAL(rotationChanged(int)), TQT_SLOT(slotChangeStencilRotation(int)));
+  connect( m_pStencilGeometryPanel, TQ_SIGNAL(positionChanged(double, double)), this, TQ_SLOT(slotChangeStencilPosition(double, double)) );
+  connect( m_pStencilGeometryPanel, TQ_SIGNAL(sizeChanged(double, double)), this, TQ_SLOT(slotChangeStencilSize(double, double)) );
+//   connect(m_pStencilGeometryPanel, TQ_SIGNAL(rotationChanged(int)), TQ_SLOT(slotChangeStencilRotation(int)));
 
-  connect( m_pDoc, TQT_SIGNAL(unitChanged(KoUnit::Unit)), m_pStencilGeometryPanel, TQT_SLOT(setUnit(KoUnit::Unit)) );
+  connect( m_pDoc, TQ_SIGNAL(unitChanged(KoUnit::Unit)), m_pStencilGeometryPanel, TQ_SLOT(setUnit(KoUnit::Unit)) );
 }
 
 void KivioView::createBirdEyeDock()
@@ -380,149 +380,149 @@ void KivioView::setupActions()
 {
   KivioStencilSetAction* addStSet =  new KivioStencilSetAction( i18n("Add Stencil Set"),
     "open_stencilset", actionCollection(), "addStencilSet" );
-  connect(addStSet,TQT_SIGNAL(activated(const TQString&)),TQT_SLOT(addStencilSet(const TQString&)));
-  connect(TQT_TQOBJECT(this), TQT_SIGNAL(updateStencilSetList()), addStSet, TQT_SLOT(updateMenu()));
-  connect(addStSet, TQT_SIGNAL(showDialog()), TQT_TQOBJECT(this), TQT_SLOT(showAddStencilSetDialog()));
+  connect(addStSet,TQ_SIGNAL(activated(const TQString&)),TQ_SLOT(addStencilSet(const TQString&)));
+  connect(this, TQ_SIGNAL(updateStencilSetList()), addStSet, TQ_SLOT(updateMenu()));
+  connect(addStSet, TQ_SIGNAL(showDialog()), this, TQ_SLOT(showAddStencilSetDialog()));
 
-  m_alignAndDistribute = new TDEAction( i18n("Align && Distribute..."), CTRL+ALT+Key_A, TQT_TQOBJECT(this),
-    TQT_SLOT(alignStencilsDlg()), actionCollection(), "alignStencils" );
+  m_alignAndDistribute = new TDEAction( i18n("Align && Distribute..."), CTRL+ALT+Key_A, this,
+    TQ_SLOT(alignStencilsDlg()), actionCollection(), "alignStencils" );
 
-  m_editCut = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT(cutStencil()), actionCollection(), "cutStencil" );
-  m_editCopy = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT(copyStencil()), actionCollection(), "copyStencil" );
-  m_editPaste = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT(pasteStencil()), actionCollection(), "pasteStencil" );
-  connect(TQApplication::clipboard(), TQT_SIGNAL(dataChanged()), TQT_TQOBJECT(this), TQT_SLOT(clipboardDataChanged()));
+  m_editCut = KStdAction::cut( this, TQ_SLOT(cutStencil()), actionCollection(), "cutStencil" );
+  m_editCopy = KStdAction::copy( this, TQ_SLOT(copyStencil()), actionCollection(), "copyStencil" );
+  m_editPaste = KStdAction::paste( this, TQ_SLOT(pasteStencil()), actionCollection(), "pasteStencil" );
+  connect(TQApplication::clipboard(), TQ_SIGNAL(dataChanged()), this, TQ_SLOT(clipboardDataChanged()));
 
-  m_selectAll = KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(selectAllStencils()), actionCollection(), "selectAllStencils");
-  m_selectNone = KStdAction::deselect(TQT_TQOBJECT(this), TQT_SLOT(unselectAllStencils()), actionCollection(), "unselectAllStencils");
+  m_selectAll = KStdAction::selectAll(this, TQ_SLOT(selectAllStencils()), actionCollection(), "selectAllStencils");
+  m_selectNone = KStdAction::deselect(this, TQ_SLOT(unselectAllStencils()), actionCollection(), "unselectAllStencils");
 
-  m_groupAction = new TDEAction( i18n("Group Selection"), "group", CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT(groupStencils()), actionCollection(), "groupStencils" );
+  m_groupAction = new TDEAction( i18n("Group Selection"), "group", CTRL+Key_G, this, TQ_SLOT(groupStencils()), actionCollection(), "groupStencils" );
   m_groupAction->setWhatsThis(i18n("Group selected objects into a single stencil"));
-  m_ungroupAction = new TDEAction( i18n("Ungroup"), "ungroup", CTRL+SHIFT+Key_G, TQT_TQOBJECT(this), TQT_SLOT(ungroupStencils()), actionCollection(), "ungroupStencils" );
+  m_ungroupAction = new TDEAction( i18n("Ungroup"), "ungroup", CTRL+SHIFT+Key_G, this, TQ_SLOT(ungroupStencils()), actionCollection(), "ungroupStencils" );
   m_ungroupAction->setWhatsThis(i18n("Break up a selected group stencil"));
 
-  m_stencilToFront = new TDEAction( i18n("Bring to Front"), "bring_forward", 0, TQT_TQOBJECT(this), TQT_SLOT(bringStencilToFront()), actionCollection(), "bringStencilToFront" );
-  m_stencilToBack = new TDEAction( i18n("Send to Back"), "send_backward", 0, TQT_TQOBJECT(this), TQT_SLOT(sendStencilToBack()), actionCollection(), "sendStencilToBack" );
+  m_stencilToFront = new TDEAction( i18n("Bring to Front"), "bring_forward", 0, this, TQ_SLOT(bringStencilToFront()), actionCollection(), "bringStencilToFront" );
+  m_stencilToBack = new TDEAction( i18n("Send to Back"), "send_backward", 0, this, TQ_SLOT(sendStencilToBack()), actionCollection(), "sendStencilToBack" );
 
-  m_menuTextFormatAction = new TDEAction(i18n("&Text..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(textFormat()),
+  m_menuTextFormatAction = new TDEAction(i18n("&Text..."), 0, 0, this, TQ_SLOT(textFormat()),
   actionCollection(), "textFormat");
 
-  m_menuStencilConnectorsAction = new TDEAction(i18n("&Stencils && Connectors..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(stencilFormat()),
+  m_menuStencilConnectorsAction = new TDEAction(i18n("&Stencils && Connectors..."), 0, 0, this, TQ_SLOT(stencilFormat()),
   actionCollection(), "stencilFormat");
 
-  m_arrowHeadsMenuAction = new TDEAction(i18n("&Arrowheads..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(arrowHeadFormat()),
+  m_arrowHeadsMenuAction = new TDEAction(i18n("&Arrowheads..."), 0, 0, this, TQ_SLOT(arrowHeadFormat()),
   actionCollection(), "arrowHeadFormat");
   m_arrowHeadsMenuAction->setWhatsThis(i18n("Arrowheads allow you to add an arrow to the beginning and/or end of a line."));
 
   /* Create the fg color button */
   m_setFGColor = new TTDESelectColorAction( i18n("Line Color"), TTDESelectColorAction::LineColor, actionCollection(), "setFGColor" );
   m_setFGColor->setWhatsThis(i18n("The line color allows you to choose a color for the lines of the stencils."));
-  connect(m_setFGColor,TQT_SIGNAL(activated()),TQT_SLOT(setFGColor()));
+  connect(m_setFGColor,TQ_SIGNAL(activated()),TQ_SLOT(setFGColor()));
   m_setBGColor = new TTDESelectColorAction( i18n("Fill Color"), TTDESelectColorAction::FillColor, actionCollection(), "setBGColor" );
   m_setBGColor->setWhatsThis(i18n("You can choose a color for the background of a stencil by using this button."));
-  connect(m_setBGColor,TQT_SIGNAL(activated()),TQT_SLOT(setBGColor()));
+  connect(m_setBGColor,TQ_SIGNAL(activated()),TQ_SLOT(setBGColor()));
 
   // Text bar
   m_setFontFamily = new TDEFontAction( i18n( "Font Family" ), 0, actionCollection(), "setFontFamily" );
-  connect( m_setFontFamily, TQT_SIGNAL(activated(const TQString&)), TQT_SLOT(setFontFamily(const TQString&)) );
+  connect( m_setFontFamily, TQ_SIGNAL(activated(const TQString&)), TQ_SLOT(setFontFamily(const TQString&)) );
 
   m_setFontSize = new TDEFontSizeAction( i18n( "Font Size" ), 0, actionCollection(), "setFontSize" );
-  connect( m_setFontSize, TQT_SIGNAL( fontSizeChanged( int ) ),
-           TQT_TQOBJECT(this), TQT_SLOT( setFontSize(int ) ) );
+  connect( m_setFontSize, TQ_SIGNAL( fontSizeChanged( int ) ),
+           this, TQ_SLOT( setFontSize(int ) ) );
 
 
   m_setTextColor = new TTDESelectColorAction( i18n("Text Color"), TTDESelectColorAction::TextColor, actionCollection(), "setTextColor" );
-  connect( m_setTextColor, TQT_SIGNAL(activated()), TQT_SLOT(setTextColor()) );
+  connect( m_setTextColor, TQ_SIGNAL(activated()), TQ_SLOT(setTextColor()) );
 
   m_setBold = new TDEToggleAction( i18n("Toggle Bold Text"), "format-text-bold", 0, actionCollection(), "setFontBold" );
-  connect( m_setBold, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleFontBold(bool)) );
+  connect( m_setBold, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleFontBold(bool)) );
 
   m_setItalics = new TDEToggleAction( i18n("Toggle Italics Text"), "format-text-italic", 0, actionCollection(), "setFontItalics" );
-  connect( m_setItalics, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleFontItalics(bool)) );
+  connect( m_setItalics, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleFontItalics(bool)) );
 
   m_setUnderline = new TDEToggleAction( i18n("Toggle Underline Text"), "format-text-underline", 0, actionCollection(), "setFontUnderline" );
-  connect( m_setUnderline, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleFontUnderline(bool)));
+  connect( m_setUnderline, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleFontUnderline(bool)));
 
   m_textAlignLeft = new TDEToggleAction( i18n( "Align &Left" ), "format-text-direction-ltr", CTRL + Key_L,
-                                    TQT_TQOBJECT(this), TQT_SLOT( textAlignLeft() ),
+                                    this, TQ_SLOT( textAlignLeft() ),
                                     actionCollection(), "textAlignLeft" );
   m_textAlignLeft->setExclusiveGroup( "align" );
   m_textAlignCenter = new TDEToggleAction( i18n( "Align &Center" ), "text_center", CTRL + ALT + Key_C,
-                                      TQT_TQOBJECT(this), TQT_SLOT( textAlignCenter() ),
+                                      this, TQ_SLOT( textAlignCenter() ),
                                       actionCollection(), "textAlignCenter" );
   m_textAlignCenter->setExclusiveGroup( "align" );
   m_textAlignCenter->setChecked( TRUE );
   m_textAlignRight = new TDEToggleAction( i18n( "Align &Right" ), "format-text-direction-rtl", CTRL + ALT + Key_R,
-                                      TQT_TQOBJECT(this), TQT_SLOT( textAlignRight() ),
+                                      this, TQ_SLOT( textAlignRight() ),
                                       actionCollection(), "textAlignRight" );
   m_textAlignRight->setExclusiveGroup( "align" );
   m_textVAlignSuper = new TDEToggleAction( i18n( "Superscript" ), "super", 0,
-                                            TQT_TQOBJECT(this), TQT_SLOT( textSuperScript() ),
+                                            this, TQ_SLOT( textSuperScript() ),
                                             actionCollection(), "textVAlignSuper" );
   m_textVAlignSuper->setExclusiveGroup( "valign" );
   m_textVAlignSub = new TDEToggleAction( i18n( "Subscript" ), "sub", 0,
-                                            TQT_TQOBJECT(this), TQT_SLOT( textSubScript() ),
+                                            this, TQ_SLOT( textSubScript() ),
                                             actionCollection(), "textVAlignSub" );
   m_textVAlignSub->setExclusiveGroup( "valign" );
 
-  m_lineWidthAction = new KoLineWidthAction(i18n("Line Width"), "linewidth", TQT_TQOBJECT(this), TQT_SLOT(setLineWidth(double)),
+  m_lineWidthAction = new KoLineWidthAction(i18n("Line Width"), "linewidth", this, TQ_SLOT(setLineWidth(double)),
     actionCollection(), "setLineWidth");
   m_lineWidthAction->setUnit(m_pDoc->unit());
-  connect(m_pDoc, TQT_SIGNAL(unitChanged(KoUnit::Unit)), m_lineWidthAction, TQT_SLOT(setUnit(KoUnit::Unit)));
+  connect(m_pDoc, TQ_SIGNAL(unitChanged(KoUnit::Unit)), m_lineWidthAction, TQ_SLOT(setUnit(KoUnit::Unit)));
 
-  m_lineStyleAction = new KoLineStyleAction(i18n("Line Style"), "linestyle", TQT_TQOBJECT(this), TQT_SLOT(setLineStyle(int)),
+  m_lineStyleAction = new KoLineStyleAction(i18n("Line Style"), "linestyle", this, TQ_SLOT(setLineStyle(int)),
     actionCollection(), "setLineStyle");
 
-  m_paperLayout = new TDEAction( i18n("Page Layout..."), 0, TQT_TQOBJECT(this), TQT_SLOT(paperLayoutDlg()), actionCollection(), "paperLayout" );
-  m_insertPage = new TDEAction( i18n("Insert Page"),"item_add", 0, TQT_TQOBJECT(this), TQT_SLOT(insertPage()), actionCollection(), "insertPage" );
-  m_removePage = new TDEAction( i18n("Remove Page"), "item_remove",0,TQT_TQOBJECT(this), TQT_SLOT(removePage()), actionCollection(), "removePage" );
+  m_paperLayout = new TDEAction( i18n("Page Layout..."), 0, this, TQ_SLOT(paperLayoutDlg()), actionCollection(), "paperLayout" );
+  m_insertPage = new TDEAction( i18n("Insert Page"),"item_add", 0, this, TQ_SLOT(insertPage()), actionCollection(), "insertPage" );
+  m_removePage = new TDEAction( i18n("Remove Page"), "item_remove",0,this, TQ_SLOT(removePage()), actionCollection(), "removePage" );
 
-  m_renamePage = new TDEAction( i18n("Rename Page..."), "item_rename",0,TQT_TQOBJECT(this), TQT_SLOT(renamePage()), actionCollection(), "renamePage" );
+  m_renamePage = new TDEAction( i18n("Rename Page..."), "item_rename",0,this, TQ_SLOT(renamePage()), actionCollection(), "renamePage" );
 
-  m_showPage = new TDEAction( i18n("Show Page..."),0 ,TQT_TQOBJECT(this),TQT_SLOT(showPage()), actionCollection(), "showPage" );
-  m_hidePage = new TDEAction( i18n("Hide Page"),0 ,TQT_TQOBJECT(this),TQT_SLOT(hidePage()), actionCollection(), "hidePage" );
+  m_showPage = new TDEAction( i18n("Show Page..."),0 ,this,TQ_SLOT(showPage()), actionCollection(), "showPage" );
+  m_hidePage = new TDEAction( i18n("Hide Page"),0 ,this,TQ_SLOT(hidePage()), actionCollection(), "hidePage" );
 
   showPageMargins = new TDEToggleAction( i18n("Show Page Margins"), "view_margins", 0, actionCollection(), "showPageMargins" );
-  connect( showPageMargins, TQT_SIGNAL(toggled(bool)), TQT_SLOT(togglePageMargins(bool)));
+  connect( showPageMargins, TQ_SIGNAL(toggled(bool)), TQ_SLOT(togglePageMargins(bool)));
 #if KDE_IS_VERSION(3,2,90)
   showPageMargins->setCheckedState(i18n("Hide Page Margins"));
 #endif
 
   showRulers = new TDEToggleAction( i18n("Show Rulers"), "view_ruler", 0, actionCollection(), "showRulers" );
-  connect( showRulers, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleShowRulers(bool)));
+  connect( showRulers, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleShowRulers(bool)));
 #if KDE_IS_VERSION(3,2,90)
   showRulers->setCheckedState(i18n("Hide Rulers"));
 #endif
 
   // Grid actions
   showGrid = new TDEToggleAction( i18n("Show Grid"), "view_grid", 0, actionCollection(), "showGrid" );
-  connect( showGrid, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleShowGrid(bool)));
+  connect( showGrid, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleShowGrid(bool)));
 #if KDE_IS_VERSION(3,2,90)
   showGrid->setCheckedState(i18n("Hide Grid"));
 #endif
 
   TDEToggleAction* snapGrid = new TDEToggleAction( i18n("Snap Grid"), "view_grid", 0, actionCollection(), "snapGrid" );
-  connect( snapGrid, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleSnapGrid(bool)));
+  connect( snapGrid, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleSnapGrid(bool)));
 
   // Guides actions
   showGuides = new TDEToggleAction( i18n("Guide Lines"), 0, actionCollection(), "showGuides" );
-  connect( showGuides, TQT_SIGNAL(toggled(bool)), TQT_SLOT(toggleShowGuides(bool)));
-  TDEAction* addGuide = new TDEAction(i18n("Add Guide Line..."), 0, TQT_TQOBJECT(this), TQT_SLOT(addGuideLine()),
+  connect( showGuides, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleShowGuides(bool)));
+  TDEAction* addGuide = new TDEAction(i18n("Add Guide Line..."), 0, this, TQ_SLOT(addGuideLine()),
     actionCollection(), "addGuideLine");
-  connect(showGuides, TQT_SIGNAL(toggled(bool)), addGuide, TQT_SLOT(setEnabled(bool)));
+  connect(showGuides, TQ_SIGNAL(toggled(bool)), addGuide, TQ_SLOT(setEnabled(bool)));
   //--
 
   m_setArrowHeads = new KivioArrowHeadAction(i18n("Arrowheads"), "arrowheads", actionCollection(), "arrowHeads");
   m_setArrowHeads->setWhatsThis(i18n("Arrowheads allow you to add an arrow to the beginning and/or end of a line."));
-  connect( m_setArrowHeads, TQT_SIGNAL(endChanged(int)), TQT_SLOT(slotSetEndArrow(int)));
-  connect( m_setArrowHeads, TQT_SIGNAL(startChanged(int)), TQT_SLOT(slotSetStartArrow(int)));
+  connect( m_setArrowHeads, TQ_SIGNAL(endChanged(int)), TQ_SLOT(slotSetEndArrow(int)));
+  connect( m_setArrowHeads, TQ_SIGNAL(startChanged(int)), TQ_SLOT(slotSetStartArrow(int)));
 
-  KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsDialog()), actionCollection(), "options");
+  KStdAction::preferences(this, TQ_SLOT(optionsDialog()), actionCollection(), "options");
 
-  (void) new TDEAction(i18n("Install Stencil Set..."), 0, TQT_TQOBJECT(this),
-    TQT_SLOT(installStencilSet()), actionCollection(), "installStencilSet");
+  (void) new TDEAction(i18n("Install Stencil Set..."), 0, this,
+    TQ_SLOT(installStencilSet()), actionCollection(), "installStencilSet");
 
   m_editDelete = new TDEAction(i18n("Delete"), "edit-delete", Key_Delete,
-    TQT_TQOBJECT(this), TQT_SLOT(deleteObject()), actionCollection(), "deleteObject");
+    this, TQ_SLOT(deleteObject()), actionCollection(), "deleteObject");
 }
 
 void KivioView::initActions()
@@ -586,10 +586,10 @@ void KivioView::addPage( KivioPage* page )
 {
   insertPage(  page );
 
-  TQObject::connect( page, TQT_SIGNAL( sig_PageHidden( KivioPage* ) ),
-                    TQT_TQOBJECT(this), TQT_SLOT( slotPageHidden( KivioPage* ) ) );
-  TQObject::connect( page, TQT_SIGNAL( sig_PageShown( KivioPage* ) ),
-                    TQT_TQOBJECT(this), TQT_SLOT( slotPageShown( KivioPage* ) ) );
+  TQObject::connect( page, TQ_SIGNAL( sig_PageHidden( KivioPage* ) ),
+                    this, TQ_SLOT( slotPageHidden( KivioPage* ) ) );
+  TQObject::connect( page, TQ_SIGNAL( sig_PageShown( KivioPage* ) ),
+                    this, TQ_SLOT( slotPageShown( KivioPage* ) ) );
 
   updatePageStatusLabel();
 }
@@ -654,8 +654,8 @@ void KivioView::setActivePage( KivioPage* page )
     return;
 
   if(m_pActivePage) {
-    disconnect(m_pActivePage, TQT_SIGNAL(sig_pageLayoutChanged(const KoPageLayout&)), this,
-      TQT_SLOT(setRulerPageLayout(const KoPageLayout&)));
+    disconnect(m_pActivePage, TQ_SIGNAL(sig_pageLayoutChanged(const KoPageLayout&)), this,
+      TQ_SLOT(setRulerPageLayout(const KoPageLayout&)));
   }
 
   m_pActivePage = page;
@@ -667,8 +667,8 @@ void KivioView::setActivePage( KivioPage* page )
 
   m_pDoc->updateView(m_pActivePage);
   setRulerPageLayout(m_pActivePage->paperLayout());
-  connect(m_pActivePage, TQT_SIGNAL(sig_pageLayoutChanged(const KoPageLayout&)),
-    TQT_SLOT(setRulerPageLayout(const KoPageLayout&)));
+  connect(m_pActivePage, TQ_SIGNAL(sig_pageLayoutChanged(const KoPageLayout&)),
+    TQ_SLOT(setRulerPageLayout(const KoPageLayout&)));
 
   m_pCanvas->guideLines().setGuideLines(m_pActivePage->horizontalGuideLines(),
     m_pActivePage->verticalGuideLines());
@@ -950,10 +950,10 @@ void KivioView::addSpawnerToStackBar( KivioStencilSpawnerSet *pSpawner )
   }
 
   KivioIconView *pView = new KivioIconView(m_pDoc->isReadWrite());
-  TQObject::connect(pView, TQT_SIGNAL(createNewStencil(KivioStencilSpawner*)), this,
-                   TQT_SLOT(addStencilFromSpawner(KivioStencilSpawner*)));
-  connect(pView, TQT_SIGNAL(stencilSelected(KivioStencilSpawner*)),
-          m_addStencilTool, TQT_SLOT(activateNewStencil(KivioStencilSpawner* )));
+  TQObject::connect(pView, TQ_SIGNAL(createNewStencil(KivioStencilSpawner*)), this,
+                   TQ_SLOT(addStencilFromSpawner(KivioStencilSpawner*)));
+  connect(pView, TQ_SIGNAL(stencilSelected(KivioStencilSpawner*)),
+          m_addStencilTool, TQ_SLOT(activateNewStencil(KivioStencilSpawner* )));
 
   pView->setStencilSpawnerSet(pSpawner);
   m_pStencilBarDockManager->insertStencilSet(pView, pSpawner->name());
@@ -1960,11 +1960,9 @@ void KivioView::textSubScript()
 void KivioView::showAlign( int align )
 {
   switch ( align ) {
-#ifndef USE_QT4
     case TQt::AlignAuto: // In left-to-right mode it's align left. TODO: alignright if text->isRightToLeft()
       kdWarning(43000) << k_funcinfo << "shouldn't be called with AlignAuto" << endl;
       // fallthrough
-#endif // USE_QT4
     case TQt::AlignLeft:
       m_textAlignLeft->setChecked( true );
       break;
@@ -2264,8 +2262,8 @@ void KivioView::showAddStencilSetDialog()
 {
   if(!m_addStencilSetDialog) {
     m_addStencilSetDialog = new Kivio::AddStencilSetDialog(this, "AddStencilSetDialog");
-    connect(m_addStencilSetDialog, TQT_SIGNAL(addStencilSet(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(addStencilSet(const TQString&)));
-    connect(TQT_TQOBJECT(this), TQT_SIGNAL(updateStencilSetList()), m_addStencilSetDialog, TQT_SLOT(updateList()));
+    connect(m_addStencilSetDialog, TQ_SIGNAL(addStencilSet(const TQString&)), this, TQ_SLOT(addStencilSet(const TQString&)));
+    connect(this, TQ_SIGNAL(updateStencilSetList()), m_addStencilSetDialog, TQ_SLOT(updateList()));
   }
 
   m_addStencilSetDialog->show();
