@@ -29,7 +29,7 @@ namespace KPlato
 
 class Factory : public KoFactory
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Factory( TQObject* parent = 0, const char* name = 0 );
