@@ -312,10 +312,10 @@ KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_vie
     pathLayout->addWidget(lable2);
     pathLayout->addWidget(path);
 
-    connect( path, TQT_SIGNAL( textChanged(const TQString&) ),
-             this, TQT_SLOT( slotChoosePath(const TQString&) ) );
-    connect( path, TQT_SIGNAL( urlSelected( const TQString&) ),
-             this, TQT_SLOT( slotChoosePath(const TQString&) ) );
+    connect( path, TQ_SIGNAL( textChanged(const TQString&) ),
+             this, TQ_SLOT( slotChoosePath(const TQString&) ) );
+    connect( path, TQ_SIGNAL( urlSelected( const TQString&) ),
+             this, TQ_SLOT( slotChoosePath(const TQString&) ) );
 
 
     TQLabel *lable1 = new TQLabel( i18n("Title:"), this, "lable1" );
@@ -331,7 +331,7 @@ KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_vie
     TQHBox *moreBox = new TQHBox( this );
     TQPushButton *showColourButton = new TQPushButton( i18n("&Set Colors"), moreBox );
     showColourButton->setToggleButton( true );
-    connect( showColourButton, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( showColourGroup(bool) ) );
+    connect( showColourButton, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( showColourGroup(bool) ) );
 
     TQVBoxLayout *topLayout = new TQVBoxLayout;
     topLayout->addWidget( helptext );
@@ -340,7 +340,7 @@ KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_vie
     topLayout->addLayout( titleLayout );
     topLayout->addWidget( moreBox );
 
-    colourGroup = new TQGroupBox( 2, Qt::Vertical,
+    colourGroup = new TQGroupBox( 2, TQt::Vertical,
                                             i18n("Preliminary Slides"),
                                             this , "colourBox" );
     TQWhatsThis::add( colourGroup,
@@ -388,9 +388,9 @@ KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_vie
     mainLayout->setResizeMode( TQLayout::Fixed );
     mainLayout->setGeometry( TQRect( 0, 0, 300, 220 ) );
 
-    connect( helpButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT ( helpMe() ) );
-    connect( cancelButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( reject() ) );
-    connect( createButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( finish() ) );
+    connect( helpButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT ( helpMe() ) );
+    connect( cancelButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( reject() ) );
+    connect( createButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( finish() ) );
 }
 
 KPrMSPresentationSetup::~KPrMSPresentationSetup()
@@ -605,7 +605,7 @@ void KPrMSPresentationCreateDialog::setupGUI()
 
     bDone->setEnabled( false );
 
-    connect( bDone, TQT_SIGNAL( clicked() ), this, TQT_SLOT( accept() ) );
+    connect( bDone, TQ_SIGNAL( clicked() ), this, TQ_SLOT( accept() ) );
 }
 
 void KPrMSPresentationCreateDialog::resizeEvent( TQResizeEvent *e )
