@@ -1522,7 +1522,7 @@ KoPen KPrObject::toPen(const TQDomElement &element) const {
     KoPen pen;
     pen.setColor(retrieveColor(element));
     if(element.hasAttribute(attrStyle))
-        pen.setStyle(static_cast<Qt::PenStyle>(element.attribute(attrStyle).toInt()));
+        pen.setStyle(static_cast<TQt::PenStyle>(element.attribute(attrStyle).toInt()));
     if(element.hasAttribute(attrWidth))
         pen.setPointWidth(element.attribute(attrWidth).toDouble());
     return pen;
@@ -1541,7 +1541,7 @@ TQBrush KPrObject::toBrush(const TQDomElement &element) const {
     TQBrush brush;
     brush.setColor(retrieveColor(element));
     if(element.hasAttribute(attrStyle))
-        brush.setStyle(static_cast<Qt::BrushStyle>(element.attribute(attrStyle).toInt()));
+        brush.setStyle(static_cast<TQt::BrushStyle>(element.attribute(attrStyle).toInt()));
     return brush;
 }
 
@@ -1845,9 +1845,9 @@ void KPrShadowObject::loadOasis(const TQDomElement &element, KoOasisContext & co
     if ( styleStack.hasAttributeNS( KoXmlNS::draw, "stroke" ))
     {
         if ( styleStack.attributeNS( KoXmlNS::draw, "stroke" ) == "none" )
-            pen.setStyle(Qt::NoPen );
+            pen.setStyle(TQt::NoPen );
         else if ( styleStack.attributeNS( KoXmlNS::draw, "stroke" ) == "solid" )
-            pen.setStyle(Qt::SolidLine );
+            pen.setStyle(TQt::SolidLine );
         else if ( styleStack.attributeNS( KoXmlNS::draw, "stroke" ) == "dash" )
         {
             TQString style = styleStack.attributeNS( KoXmlNS::draw, "stroke-dash" );
@@ -1867,25 +1867,25 @@ void KPrShadowObject::loadOasis(const TQDomElement &element, KoOasisContext & co
                          draw->attributeNS( KoXmlNS::draw, "dots1-length", TQString() )=="0.508cm" &&
                          draw->attributeNS( KoXmlNS::draw, "dots2-length", TQString() )=="0.508cm" &&
                          draw->attributeNS( KoXmlNS::draw, "distance", TQString() )=="0.508cm" )
-                        pen.setStyle(Qt::DashLine );
+                        pen.setStyle(TQt::DashLine );
                     else if ( draw->attributeNS( KoXmlNS::draw, "dots1", TQString() )=="1" &&
                               draw->attributeNS( KoXmlNS::draw, "distance", TQString() )=="0.257cm" )
-                        pen.setStyle(Qt::DotLine );
+                        pen.setStyle(TQt::DotLine );
                     else if ( draw->attributeNS( KoXmlNS::draw, "dots1", TQString() )=="1" &&
                          draw->attributeNS( KoXmlNS::draw, "dots2", TQString() )=="1" &&
                          draw->attributeNS( KoXmlNS::draw, "dots1-length", TQString() )=="0.051cm" &&
                          draw->attributeNS( KoXmlNS::draw, "dots2-length", TQString() )=="0.254cm" &&
                          draw->attributeNS( KoXmlNS::draw, "distance", TQString() )=="0.127cm" )
-                        pen.setStyle(Qt::DashDotLine );
+                        pen.setStyle(TQt::DashDotLine );
                     else if ( draw->attributeNS( KoXmlNS::draw, "dots1", TQString() )=="2" &&
                          draw->attributeNS( KoXmlNS::draw, "dots2", TQString() )=="1" &&
                          draw->attributeNS( KoXmlNS::draw, "dots2-length", TQString() )=="0.203cm" &&
                          draw->attributeNS( KoXmlNS::draw, "distance", TQString() )=="0.203cm" )
-                        pen.setStyle(Qt::DashDotDotLine );
+                        pen.setStyle(TQt::DashDotDotLine );
                     else
                     {
                         kdDebug()<<" stroke style undefined \n";
-                        pen.setStyle(Qt::SolidLine );
+                        pen.setStyle(TQt::SolidLine );
                     }
 
                 }
