@@ -131,22 +131,22 @@ KPrTextObject::KPrTextObject(  KPrDocument *doc )
     bbottom = 0.0;
     alignVertical = 0.0;
 
-    connect( m_textobj, TQT_SIGNAL( newCommand( KCommand * ) ),
-             TQT_SLOT( slotNewCommand( KCommand * ) ) );
-    connect( m_textobj, TQT_SIGNAL( availableHeightNeeded() ),
-             TQT_SLOT( slotAvailableHeightNeeded() ) );
-    connect( m_textobj, TQT_SIGNAL( repaintChanged( KoTextObject* ) ),
-             TQT_SLOT( slotRepaintChanged() ) );
+    connect( m_textobj, TQ_SIGNAL( newCommand( KCommand * ) ),
+             TQ_SLOT( slotNewCommand( KCommand * ) ) );
+    connect( m_textobj, TQ_SIGNAL( availableHeightNeeded() ),
+             TQ_SLOT( slotAvailableHeightNeeded() ) );
+    connect( m_textobj, TQ_SIGNAL( repaintChanged( KoTextObject* ) ),
+             TQ_SLOT( slotRepaintChanged() ) );
 
     // Send our "repaintChanged" signals to the document.
-    connect( this, TQT_SIGNAL( repaintChanged( KPrTextObject * ) ),
-             m_doc, TQT_SLOT( slotRepaintChanged( KPrTextObject * ) ) );
-    connect(m_textobj, TQT_SIGNAL( showFormatObject(const KoTextFormat &) ),
-            TQT_SLOT( slotFormatChanged(const KoTextFormat &)) );
-    connect( m_textobj, TQT_SIGNAL( afterFormatting( int, KoTextParag*, bool* ) ),
-             TQT_SLOT( slotAfterFormatting( int, KoTextParag*, bool* ) ) );
-    connect( m_textobj, TQT_SIGNAL( paragraphDeleted( KoTextParag*) ),
-             TQT_SLOT( slotParagraphDeleted(KoTextParag*) ));
+    connect( this, TQ_SIGNAL( repaintChanged( KPrTextObject * ) ),
+             m_doc, TQ_SLOT( slotRepaintChanged( KPrTextObject * ) ) );
+    connect(m_textobj, TQ_SIGNAL( showFormatObject(const KoTextFormat &) ),
+            TQ_SLOT( slotFormatChanged(const KoTextFormat &)) );
+    connect( m_textobj, TQ_SIGNAL( afterFormatting( int, KoTextParag*, bool* ) ),
+             TQ_SLOT( slotAfterFormatting( int, KoTextParag*, bool* ) ) );
+    connect( m_textobj, TQ_SIGNAL( paragraphDeleted( KoTextParag*) ),
+             TQ_SLOT( slotParagraphDeleted(KoTextParag*) ));
 
 }
 
@@ -476,7 +476,7 @@ void KPrTextObject::drawText( TQPainter* _painter, KoTextZoomHandler *zoomHandle
     _painter->save();
     _painter->translate( m_doc->zoomHandler()->zoomItX( bLeft()), m_doc->zoomHandler()->zoomItY( bTop()+alignVertical));
     if ( !editingTextObj || (_painter->device() && _painter->device()->devType() == TQInternal::Printer))
-        cg.setBrush( TQColorGroup::Base, Qt::NoBrush );
+        cg.setBrush( TQColorGroup::Base, TQt::NoBrush );
     else
         cg.setColor( TQColorGroup::Base, m_doc->txtBackCol() );
 
@@ -1778,12 +1778,12 @@ KPrTextView::KPrTextView( KPrTextObject * txtObj, KPrCanvas *_canvas, bool temp
     m_kptextobj=txtObj;
     if (temp)
       return;
-    connect( txtObj->textObject(), TQT_SIGNAL( selectionChanged(bool) ),
-             m_canvas, TQT_SIGNAL( selectionChanged(bool) ) );
+    connect( txtObj->textObject(), TQ_SIGNAL( selectionChanged(bool) ),
+             m_canvas, TQ_SIGNAL( selectionChanged(bool) ) );
     KoTextView::setReadWrite( txtObj->kPresenterDocument()->isReadWrite() );
-    connect( textView(), TQT_SIGNAL( cut() ), TQT_SLOT( cut() ) );
-    connect( textView(), TQT_SIGNAL( copy() ), TQT_SLOT( copy() ) );
-    connect( textView(), TQT_SIGNAL( paste() ), TQT_SLOT( paste() ) );
+    connect( textView(), TQ_SIGNAL( cut() ), TQ_SLOT( cut() ) );
+    connect( textView(), TQ_SIGNAL( copy() ), TQ_SLOT( copy() ) );
+    connect( textView(), TQ_SIGNAL( paste() ), TQ_SLOT( paste() ) );
     updateUI( true, true );
 
     txtObj->setEditingTextObj( true );
@@ -1803,8 +1803,8 @@ KoTextViewIface* KPrTextView::dcopObject()
 
 void KPrTextView::terminate(bool removeSelection)
 {
-    disconnect( textView()->textObject(), TQT_SIGNAL( selectionChanged(bool) ),
-                m_canvas, TQT_SIGNAL( selectionChanged(bool) ) );
+    disconnect( textView()->textObject(), TQ_SIGNAL( selectionChanged(bool) ),
+                m_canvas, TQ_SIGNAL( selectionChanged(bool) ) );
     textView()->terminate(removeSelection);
 }
 
@@ -2368,7 +2368,7 @@ TQDragObject * KPrTextView::newDrag( TQWidget * parent )
 {
     TQBuffer buffer;
     const TQCString mimeType = "application/vnd.oasis.opendocument.text";
-    KoStore * store = KoStore::createStore( TQT_TQIODEVICE(&buffer), KoStore::Write, mimeType );
+    KoStore * store = KoStore::createStore( &buffer, KoStore::Write, mimeType );
     Q_ASSERT( store );
     Q_ASSERT( !store->bad() );
 
@@ -2570,7 +2570,7 @@ void KPrTextObject::saveParagraph( TQDomDocument& doc,KoTextParag * parag,TQDomE
 
 KoPen KPrTextObject::defaultPen() const
 {
-    return KoPen( TQt::black, 1.0, Qt::NoPen );
+    return KoPen( TQt::black, 1.0, TQt::NoPen );
 }
 
 TQPoint KPrTextObject::viewToInternal( const TQPoint & pos, KPrCanvas* canvas ) const
