@@ -54,7 +54,7 @@ class View;
 */
 class CSVDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
