@@ -413,16 +413,16 @@ DatabaseDialog::DatabaseDialog( View * parent, TQRect const & rect, const char *
   finishButton()->setEnabled(false);
 
   // signals and slots connections
-  connect( m_orBox, TQT_SIGNAL( clicked() ), this, TQT_SLOT( orBox_clicked() ) );
-  connect( m_andBox, TQT_SIGNAL( clicked() ), this, TQT_SLOT( andBox_clicked() ) );
-  connect( m_startingCell, TQT_SIGNAL( clicked() ), this, TQT_SLOT( startingCell_clicked() ) );
-  connect( m_startingRegion, TQT_SIGNAL( clicked() ), this, TQT_SLOT( startingRegion_clicked() ) );
-  connect( m_driver, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( databaseDriverChanged(int) ) );
-  connect( m_host, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( databaseHostChanged(const TQString &) ) );
-  connect( m_databaseName, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( databaseNameChanged(const TQString &) ) );
-  connect( m_sheetView, TQT_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint &, int ) ),
-           this, TQT_SLOT( popupSheetViewMenu(TQListViewItem *, const TQPoint &, int ) ) );
-  connect( m_sheetView, TQT_SIGNAL( clicked( TQListViewItem * ) ), this, TQT_SLOT( sheetViewClicked( TQListViewItem * ) ) );
+  connect( m_orBox, TQ_SIGNAL( clicked() ), this, TQ_SLOT( orBox_clicked() ) );
+  connect( m_andBox, TQ_SIGNAL( clicked() ), this, TQ_SLOT( andBox_clicked() ) );
+  connect( m_startingCell, TQ_SIGNAL( clicked() ), this, TQ_SLOT( startingCell_clicked() ) );
+  connect( m_startingRegion, TQ_SIGNAL( clicked() ), this, TQ_SLOT( startingRegion_clicked() ) );
+  connect( m_driver, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( databaseDriverChanged(int) ) );
+  connect( m_host, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( databaseHostChanged(const TQString &) ) );
+  connect( m_databaseName, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( databaseNameChanged(const TQString &) ) );
+  connect( m_sheetView, TQ_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint &, int ) ),
+           this, TQ_SLOT( popupSheetViewMenu(TQListViewItem *, const TQPoint &, int ) ) );
+  connect( m_sheetView, TQ_SIGNAL( clicked( TQListViewItem * ) ), this, TQ_SLOT( sheetViewClicked( TQListViewItem * ) ) );
 
   TQStringList str = TQSqlDatabase::drivers();
   m_driver->insertItem("");
