@@ -165,38 +165,38 @@ FormulaDialog::FormulaDialog( View* parent, const char* name,const TQString& for
 
     refresh_result = true;
 
-    connect( this, TQT_SIGNAL( cancelClicked() ), this, TQT_SLOT( slotClose() ) );
-    connect( this, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( slotOk() ) );
-    connect( typeFunction, TQT_SIGNAL( activated(const TQString &) ),
-             this, TQT_SLOT( slotActivated(const TQString &) ) );
-    connect( functions, TQT_SIGNAL( highlighted(const TQString &) ),
-             this, TQT_SLOT( slotSelected(const TQString &) ) );
-    connect( functions, TQT_SIGNAL( selected(const TQString &) ),
-             this, TQT_SLOT( slotSelected(const TQString &) ) );
-    connect( functions, TQT_SIGNAL( doubleClicked(TQListBoxItem * ) ),
-             this ,TQT_SLOT( slotDoubleClicked(TQListBoxItem *) ) );
+    connect( this, TQ_SIGNAL( cancelClicked() ), this, TQ_SLOT( slotClose() ) );
+    connect( this, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( slotOk() ) );
+    connect( typeFunction, TQ_SIGNAL( activated(const TQString &) ),
+             this, TQ_SLOT( slotActivated(const TQString &) ) );
+    connect( functions, TQ_SIGNAL( highlighted(const TQString &) ),
+             this, TQ_SLOT( slotSelected(const TQString &) ) );
+    connect( functions, TQ_SIGNAL( selected(const TQString &) ),
+             this, TQ_SLOT( slotSelected(const TQString &) ) );
+    connect( functions, TQ_SIGNAL( doubleClicked(TQListBoxItem * ) ),
+             this ,TQ_SLOT( slotDoubleClicked(TQListBoxItem *) ) );
 
     slotActivated(i18n("All"));
 
-    connect( selectFunction, TQT_SIGNAL(clicked()),
-	     this,TQT_SLOT(slotSelectButton()));
+    connect( selectFunction, TQ_SIGNAL(clicked()),
+	     this,TQ_SLOT(slotSelectButton()));
 
-    connect( firstElement,TQT_SIGNAL(textChanged ( const TQString & )),
-	     this,TQT_SLOT(slotChangeText(const TQString &)));
-    connect( secondElement,TQT_SIGNAL(textChanged ( const TQString & )),
-	     this,TQT_SLOT(slotChangeText(const TQString &)));
-    connect( thirdElement,TQT_SIGNAL(textChanged ( const TQString & )),
-	     this,TQT_SLOT(slotChangeText(const TQString &)));
-    connect( fourElement,TQT_SIGNAL(textChanged ( const TQString & )),
-	     this,TQT_SLOT(slotChangeText(const TQString &)));
-    connect( fiveElement,TQT_SIGNAL(textChanged ( const TQString & )),
-	     this,TQT_SLOT(slotChangeText(const TQString &)));
+    connect( firstElement,TQ_SIGNAL(textChanged ( const TQString & )),
+	     this,TQ_SLOT(slotChangeText(const TQString &)));
+    connect( secondElement,TQ_SIGNAL(textChanged ( const TQString & )),
+	     this,TQ_SLOT(slotChangeText(const TQString &)));
+    connect( thirdElement,TQ_SIGNAL(textChanged ( const TQString & )),
+	     this,TQ_SLOT(slotChangeText(const TQString &)));
+    connect( fourElement,TQ_SIGNAL(textChanged ( const TQString & )),
+	     this,TQ_SLOT(slotChangeText(const TQString &)));
+    connect( fiveElement,TQ_SIGNAL(textChanged ( const TQString & )),
+	     this,TQ_SLOT(slotChangeText(const TQString &)));
 
-    connect( m_pView->choice(), TQT_SIGNAL(changed(const Region&)),
-             this, TQT_SLOT(slotSelectionChanged()));
+    connect( m_pView->choice(), TQ_SIGNAL(changed(const Region&)),
+             this, TQ_SLOT(slotSelectionChanged()));
 
-    connect( m_browser, TQT_SIGNAL( linkClicked( const TQString& ) ),
-             this, TQT_SLOT( slotShowFunction( const TQString& ) ) );
+    connect( m_browser, TQ_SIGNAL( linkClicked( const TQString& ) ),
+             this, TQ_SLOT( slotShowFunction( const TQString& ) ) );
 
     // Save the name of the active sheet.
     m_sheetName = m_pView->activeSheet()->sheetName();
@@ -240,10 +240,10 @@ FormulaDialog::FormulaDialog( View* parent, const char* name,const TQString& for
     if( functions->currentItem() == -1 )
         selectFunction->setEnabled( false );
 
-    connect( searchFunct, TQT_SIGNAL( textChanged( const TQString & ) ),
-	     this, TQT_SLOT( slotSearchText(const TQString &) ) );
-    connect( searchFunct, TQT_SIGNAL( returnPressed() ),
-	     this, TQT_SLOT( slotPressReturn() ) );
+    connect( searchFunct, TQ_SIGNAL( textChanged( const TQString & ) ),
+	     this, TQ_SLOT( slotSearchText(const TQString &) ) );
+    connect( searchFunct, TQ_SIGNAL( returnPressed() ),
+	     this, TQ_SLOT( slotPressReturn() ) );
 }
 
 FormulaDialog::~FormulaDialog()
@@ -547,7 +547,7 @@ static void showEntry( TQLineEdit* edit, TQLabel* label,
         edit->setText( "0" );
       break;
     case KSpread_Int:
-      edit->setValidator(new TQIntValidator (TQT_TQOBJECT(edit)));
+      edit->setValidator(new TQIntValidator (edit));
       edit->setText( "0" );
       break;
       }
