@@ -36,7 +36,7 @@ class Canvas;
 
 class KudesignerDoc: public KoDocument
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KudesignerDoc( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject* parent = 0, const char* name = 0, bool singleViewMode = false );
