@@ -111,8 +111,8 @@ KWCanvas::KWCanvas(const TQString& viewMode, TQWidget *parent, KWDocument *d, KW
     viewport()->setMouseTracking( TRUE );
 
     m_scrollTimer = new TQTimer( this );
-    connect( m_scrollTimer, TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( doAutoScroll() ) );
+    connect( m_scrollTimer, TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( doAutoScroll() ) );
 
     viewport()->setFocusProxy( this );
     viewport()->setFocusPolicy( TQWidget::WheelFocus );
@@ -122,17 +122,17 @@ KWCanvas::KWCanvas(const TQString& viewMode, TQWidget *parent, KWDocument *d, KW
     installEventFilter( this );
     KCursor::setAutoHideCursor( this, true, true );
 
-    connect( this, TQT_SIGNAL(contentsMoving( int, int )),
-             this, TQT_SLOT(slotContentsMoving( int, int )) );
+    connect( this, TQ_SIGNAL(contentsMoving( int, int )),
+             this, TQ_SLOT(slotContentsMoving( int, int )) );
 
-    connect( m_doc, TQT_SIGNAL( newContentsSize() ),
-             this, TQT_SLOT( slotNewContentsSize() ) );
+    connect( m_doc, TQ_SIGNAL( newContentsSize() ),
+             this, TQ_SLOT( slotNewContentsSize() ) );
 
-    connect( m_doc, TQT_SIGNAL( mainTextHeightChanged() ),
-             this, TQT_SLOT( slotMainTextHeightChanged() ) );
+    connect( m_doc, TQ_SIGNAL( mainTextHeightChanged() ),
+             this, TQ_SLOT( slotMainTextHeightChanged() ) );
 
-    connect( m_doc, TQT_SIGNAL( sig_terminateEditing( KWFrameSet * ) ),
-             this, TQT_SLOT( terminateEditing( KWFrameSet * ) ) );
+    connect( m_doc, TQ_SIGNAL( sig_terminateEditing( KWFrameSet * ) ),
+             this, TQ_SLOT( terminateEditing( KWFrameSet * ) ) );
 
     slotNewContentsSize();
 
@@ -162,10 +162,10 @@ KWCanvas::KWCanvas(const TQString& viewMode, TQWidget *parent, KWDocument *d, KW
     }
     m_doc->deleteInitialEditingInfo();
 
-    connect(frameViewManager(), TQT_SIGNAL(sigFrameResized(const TQValueList<KWFrame*>&)),
-        m_doc, TQT_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
-    connect(frameViewManager(), TQT_SIGNAL(sigFrameMoved(const TQValueList<KWFrame*>&)),
-        m_doc, TQT_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
+    connect(frameViewManager(), TQ_SIGNAL(sigFrameResized(const TQValueList<KWFrame*>&)),
+        m_doc, TQ_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
+    connect(frameViewManager(), TQ_SIGNAL(sigFrameMoved(const TQValueList<KWFrame*>&)),
+        m_doc, TQ_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
 }
 
 KWCanvas::~KWCanvas()
@@ -175,10 +175,10 @@ KWCanvas::~KWCanvas()
     m_currentFrameSetEdit = 0;
     delete m_viewMode;
     m_viewMode = 0;
-    disconnect(frameViewManager(), TQT_SIGNAL(sigFrameResized(const TQValueList<KWFrame*>&)),
-        m_doc, TQT_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
-    disconnect(frameViewManager(), TQT_SIGNAL(sigFrameMoved(const TQValueList<KWFrame*>&)),
-        m_doc, TQT_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
+    disconnect(frameViewManager(), TQ_SIGNAL(sigFrameResized(const TQValueList<KWFrame*>&)),
+        m_doc, TQ_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
+    disconnect(frameViewManager(), TQ_SIGNAL(sigFrameMoved(const TQValueList<KWFrame*>&)),
+        m_doc, TQ_SLOT(framesChanged(const TQValueList<KWFrame*>&)));
     delete m_frameViewManager;
     m_frameViewManager = 0;
 }
@@ -413,13 +413,13 @@ void KWCanvas::contentsMousePressEvent( TQMouseEvent *e )
     KoPoint docPoint = m_doc->unzoomPoint( normalPoint );
 
 
-    if ( e->button() == Qt::LeftButton )
+    if ( e->button() == TQt::LeftButton )
     {
       m_mousePressed = true;
     }
 
     // Only edit-mode (and only LMB) allowed on read-only documents (to select text)
-    if ( !m_doc->isReadWrite() && ( m_mouseMode != MM_EDIT || e->button() != Qt::LeftButton ) )
+    if ( !m_doc->isReadWrite() && ( m_mouseMode != MM_EDIT || e->button() != TQt::LeftButton ) )
         return;
     if ( m_printing )
         return;
@@ -450,7 +450,7 @@ void KWCanvas::contentsMousePressEvent( TQMouseEvent *e )
             // RMB inside a frame unselects too, except when
             //     right-clicking on a selected frame
             KWFrameView *view = m_frameViewManager->view( docPoint, KWFrameViewManager::frameOnTop );
-            if ( ! ( e->button() == Qt::RightButton && view && view->selected() ) )
+            if ( ! ( e->button() == TQt::RightButton && view && view->selected() ) )
                 selectAllFrames( false );
 
             KWFrame * frame = view ? view->frame() : 0L;
@@ -529,18 +529,18 @@ void KWCanvas::contentsMousePressEvent( TQMouseEvent *e )
     break;
     case MM_CREATE_TEXT: case MM_CREATE_PART: case MM_CREATE_TABLE:
     case MM_CREATE_FORMULA:
-        if ( e->button() == Qt::LeftButton )
+        if ( e->button() == TQt::LeftButton )
             mpCreate( normalPoint, e->state() & TQt::ShiftButton);
         break;
     case MM_CREATE_PIX:
-        if ( e->button() == Qt::LeftButton )
+        if ( e->button() == TQt::LeftButton )
             mpCreatePixmap( normalPoint, e->state() & TQt::ShiftButton );
         break;
     default: break;
     }
     m_scrollTimer->start( 50 );
 
-    if ( e->button() == Qt::MidButton ) {
+    if ( e->button() == TQt::MidButton ) {
         if ( m_doc->isReadWrite() && m_currentFrameSetEdit && m_mouseMode == MM_EDIT )
         {
             TQApplication::clipboard()->setSelectionMode( true );
@@ -548,7 +548,7 @@ void KWCanvas::contentsMousePressEvent( TQMouseEvent *e )
             TQApplication::clipboard()->setSelectionMode( false );
         }
     }
-    else if ( e->button() == Qt::RightButton ) {
+    else if ( e->button() == TQt::RightButton ) {
         if(!m_doc->isReadWrite()) // The popups are not available in readonly mode, since the GUI isn't built...
             return;
         if ( m_deleteMovingRect )
@@ -1631,7 +1631,7 @@ void KWCanvas::slotContentsMoving( int cx, int cy )
     // so that it will reposition any active embedded object.
     // This needs to be delayed since contents moving is emitted -before- moving,
     // and from resizeEvent it's too early too.
-    TQTimer::singleShot( 0, this, TQT_SIGNAL( viewTransformationsChanged() ) );
+    TQTimer::singleShot( 0, this, TQ_SIGNAL( viewTransformationsChanged() ) );
 }
 
 void KWCanvas::slotMainTextHeightChanged()
@@ -1725,7 +1725,7 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
             {
                 //  kdDebug() << " KeyPress m_currentFrameSetEdit=" << m_currentFrameSetEdit << " isRW="<<m_doc->isReadWrite() << endl;
                 //  kdDebug() << " m_printing=" << m_printing << " mousemode=" << m_mouseMode << " (MM_EDIT=" << MM_EDIT<<")"<<endl;
-                TQKeyEvent * keyev = TQT_TQKEYEVENT(e);
+                TQKeyEvent * keyev = static_cast<TQKeyEvent*>(e);
 #ifndef NDEBUG
                 // Debug keys
                 if ( ( keyev->state() & ControlButton ) && ( keyev->state() & ShiftButton ) )
@@ -1768,7 +1768,7 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
             {
                 //  kdDebug() << " KeyPress m_currentFrameSetEdit=" << m_currentFrameSetEdit << " isRW="<<m_doc->isReadWrite() << endl;
                 //  kdDebug() << " m_printing=" << m_printing << " mousemode=" << m_mouseMode << " (MM_EDIT=" << MM_EDIT<<")"<<endl;
-                TQKeyEvent * keyev = TQT_TQKEYEVENT(e);
+                TQKeyEvent * keyev = static_cast<TQKeyEvent*>(e);
                 // By default PgUp and PgDown move the scrollbars and not the caret anymore - this is done here
                 if ( !m_doc->pgUpDownMovesCaret() && ( (keyev->state() & ShiftButton) == 0 )
                      && ( keyev->key() == TQt::Key_PageUp || keyev->key() == Key_PageDown ) )
@@ -1816,10 +1816,10 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
                     TQPoint vP = m_viewMode->normalToView(normalPoint);
                     TQPoint gP = mapToGlobal(vP);
                     TQMouseEvent mevPress(TQEvent::MouseButtonPress, vP,
-                        gP, Qt::LeftButton, 0);
+                        gP, TQt::LeftButton, 0);
                     contentsMousePressEvent(&mevPress);
                     TQMouseEvent mevRelease(TQEvent::MouseButtonRelease, vP,
-                        gP, Qt::LeftButton, 0);
+                        gP, TQt::LeftButton, 0);
                     contentsMouseReleaseEvent(&mevRelease);
                 }
                 else if ( keyev->key() == TQt::Key_Escape  ) {
@@ -1879,7 +1879,7 @@ bool KWCanvas::eventFilter( TQObject *o, TQEvent *e )
             } break;
             case TQEvent::KeyRelease:
             {
-                TQKeyEvent * keyev = TQT_TQKEYEVENT(e);
+                TQKeyEvent * keyev = static_cast<TQKeyEvent*>(e);
                 if ( keyev->key() == TQt::Key_Control )
                 {
                     TQPoint mousep = mapFromGlobal(TQCursor::pos()) + TQPoint( contentsX(), contentsY() );
@@ -2062,13 +2062,13 @@ InteractionPolicy::InteractionPolicy(KWCanvas *parent, bool doInit, bool include
 }
 
 InteractionPolicy* InteractionPolicy::createPolicy(KWCanvas *parent, MouseMeaning meaning, KoPoint &point, TQt::ButtonState buttonState, TQt::ButtonState keyState) {
-    if(buttonState & Qt::LeftButton || buttonState & Qt::RightButton) {
+    if(buttonState & TQt::LeftButton || buttonState & TQt::RightButton) {
         // little inner class to make sure we don't duplicate code
         class Selector {
           public:
             Selector(KWCanvas *canvas, KoPoint &point, TQt::ButtonState buttonState, TQt::ButtonState keyState) :
                 m_canvas(canvas), m_point(point), m_state(keyState) {
-                m_leftClick = buttonState & Qt::LeftButton;
+                m_leftClick = buttonState & TQt::LeftButton;
                 KWFrameView *view = canvas->frameViewManager()->view(point,
                         KWFrameViewManager::frameOnTop);
                 m_doSomething = (view && !view->selected());
@@ -2445,7 +2445,7 @@ void FrameMovePolicy::finishInteraction() {
 FrameSelectPolicy::FrameSelectPolicy(KWCanvas *parent, MouseMeaning meaning, KoPoint &point, TQt::ButtonState buttonState, TQt::ButtonState keyState)
     : InteractionPolicy(parent, false) {
 
-    bool leftButton = buttonState & Qt::LeftButton;
+    bool leftButton = buttonState & TQt::LeftButton;
     // this is a special case; if a frame that is curently being edited is 'selected' on the border
     // we redirect that click to the text part of the frame.
     // this means we give the user a lot more space to click on the left side of the frame to
