@@ -32,7 +32,7 @@ KWInsertPageDia::KWInsertPageDia( TQWidget *parent, const char* name )
 {
     TQVBox *page = makeVBoxMainWidget();
 
-    TQButtonGroup *grp = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Insert Page" ),page );
+    TQButtonGroup *grp = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Insert Page" ),page );
     grp->setRadioButtonExclusive( TRUE );
     grp->layout();
     m_after = new TQRadioButton( i18n("After"), grp );
