@@ -32,7 +32,7 @@ KWSortDia::KWSortDia( TQWidget *parent, const char* name )
 {
     TQVBox *page = makeVBoxMainWidget();
 
-    TQButtonGroup *grp = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Sort" ),page );
+    TQButtonGroup *grp = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Sort" ),page );
     grp->setRadioButtonExclusive( TRUE );
     grp->layout();
     m_increase = new TQRadioButton( i18n("Increase"), grp );
