@@ -245,12 +245,12 @@ KWClassicMailMergeEditorList::KWClassicMailMergeEditorList( TQWidget *parent, KW
     addColumn( i18n( "Name" ) );
     addColumn( i18n( "Value" ) );
     header()->setMovingEnabled( FALSE );
-    connect( header(), TQT_SIGNAL( sizeChange( int, int, int ) ),
-             this, TQT_SLOT( columnSizeChange( int, int, int ) ) );
-//     connect( header(), TQT_SIGNAL( sectionClicked( int ) ),
-//           this, TQT_SLOT( sectionClicked( int ) ) );
-    disconnect( header(), TQT_SIGNAL( sectionClicked( int ) ),
-                this, TQT_SLOT( changeSortColumn( int ) ) );
+    connect( header(), TQ_SIGNAL( sizeChange( int, int, int ) ),
+             this, TQ_SLOT( columnSizeChange( int, int, int ) ) );
+//     connect( header(), TQ_SIGNAL( sectionClicked( int ) ),
+//           this, TQ_SLOT( sectionClicked( int ) ) );
+    disconnect( header(), TQ_SIGNAL( sectionClicked( int ) ),
+                this, TQ_SLOT( changeSortColumn( int ) ) );
 
     currentRecord = -1;
 }
@@ -343,27 +343,27 @@ KWClassicMailMergeEditor::KWClassicMailMergeEditor( TQWidget *parent, KWClassicS
     first = new TQToolButton( toolbar );
     first->setIconSet( SmallIconSet( "go-first" ) );
     first->setFixedSize( first->sizeHint() );
-    connect(first, TQT_SIGNAL(clicked()), this, TQT_SLOT(firstRecord()));
+    connect(first, TQ_SIGNAL(clicked()), this, TQ_SLOT(firstRecord()));
 
     back_ = new TQToolButton( toolbar );
     back_->setIconSet( SmallIconSet( "back" ) );
     back_->setFixedSize( back_->sizeHint() );
-    connect(back_, TQT_SIGNAL(clicked()), this, TQT_SLOT(prevRecord()));
+    connect(back_, TQ_SIGNAL(clicked()), this, TQ_SLOT(prevRecord()));
 
     records = new TQSpinBox( 1, db->getNumRecords(), 1, toolbar );
     records->setMaximumHeight( records->sizeHint().height() );
-    connect( records, TQT_SIGNAL( valueChanged( int ) ),
-             this, TQT_SLOT( changeRecord( int ) ) );
+    connect( records, TQ_SIGNAL( valueChanged( int ) ),
+             this, TQ_SLOT( changeRecord( int ) ) );
 
     forward = new TQToolButton( toolbar );
     forward->setIconSet( SmallIconSet( "forward" ) );
     forward->setFixedSize( forward->sizeHint() );
-    connect(forward, TQT_SIGNAL(clicked()), this, TQT_SLOT(nextRecord()));
+    connect(forward, TQ_SIGNAL(clicked()), this, TQ_SLOT(nextRecord()));
 
     finish = new TQToolButton( toolbar );
     finish->setIconSet( SmallIconSet( "go-last" ) );
     finish->setFixedSize( finish->sizeHint() );
-    connect(finish, TQT_SIGNAL(clicked()), this, TQT_SLOT(lastRecord()));
+    connect(finish, TQ_SIGNAL(clicked()), this, TQ_SLOT(lastRecord()));
 
     TQWidget *sep = new TQWidget( toolbar );
     sep->setMaximumWidth( 10 );
@@ -371,29 +371,29 @@ KWClassicMailMergeEditor::KWClassicMailMergeEditor( TQWidget *parent, KWClassicS
     newRecord = new TQToolButton( toolbar );
     newRecord->setIconSet( SmallIconSet( "sl_addrecord" ) );
     newRecord->setFixedSize( newRecord->sizeHint() );
-    connect( newRecord, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( addRecord() ) );
+    connect( newRecord, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( addRecord() ) );
     TQToolTip::add( newRecord, i18n( "Add record" ) );
 
     newEntry = new TQToolButton( toolbar );
     newEntry->setIconSet( SmallIconSet( "sl_addentry" ) );
     newEntry->setFixedSize( newEntry->sizeHint() );
-    connect( newEntry, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( addEntry() ) );
+    connect( newEntry, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( addEntry() ) );
     TQToolTip::add( newEntry, i18n( "Add entry" ) );
 
     deleteRecord = new TQToolButton( toolbar );
     deleteRecord->setIconSet( SmallIconSet( "sl_delrecord" ) );
     deleteRecord->setFixedSize( deleteRecord->sizeHint() );
-    connect( deleteRecord, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( removeRecord() ) );
+    connect( deleteRecord, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( removeRecord() ) );
     TQToolTip::add( deleteRecord, i18n( "Remove record" ) );
 
     deleteEntry = new TQToolButton( toolbar );
     deleteEntry->setIconSet( SmallIconSet( "sl_delentry" ) );
     deleteEntry->setFixedSize( deleteEntry->sizeHint() );
-    connect( deleteEntry, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( removeEntry() ) );
+    connect( deleteEntry, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( removeEntry() ) );
     TQToolTip::add( deleteEntry, i18n( "Remove entry" ) );
 
     dbList = new KWClassicMailMergeEditorList( back, db );
