@@ -184,7 +184,7 @@ public:
     {
         TQObject *wid = child( 0, "TQWidget" );
         if ( wid )
-            TQT_TQWIDGET(wid)->setGeometry( 0, 0, width(), height() );
+            static_cast<TQWidget*>(wid)->setGeometry( 0, 0, width(), height() );
     }
 
     virtual void childEvent( TQChildEvent *ev )
@@ -231,7 +231,7 @@ KoDocument::KoDocument( TQWidget * parentWidget, const char *widgetName, TQObjec
 
     d = new Private;
     m_bEmpty = TRUE;
-    connect( &d->m_autoSaveTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotAutoSave() ) );
+    connect( &d->m_autoSaveTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAutoSave() ) );
     setAutoSave( s_defaultAutoSave );
     d->m_bSingleViewMode = singleViewMode;
 
@@ -264,7 +264,7 @@ KoDocument::KoDocument( TQWidget * parentWidget, const char *widgetName, TQObjec
 
     // A way to 'fix' the job's window, since we have no widget known to KParts
     if ( !singleViewMode )
-        connect( this, TQT_SIGNAL( started( TDEIO::Job* ) ), TQT_SLOT( slotStarted( TDEIO::Job* ) ) );
+        connect( this, TQ_SIGNAL( started( TDEIO::Job* ) ), TQ_SLOT( slotStarted( TDEIO::Job* ) ) );
 }
 
 KoDocument::~KoDocument()
@@ -277,8 +277,8 @@ KoDocument::~KoDocument()
 
     TQPtrListIterator<KoDocumentChild> childIt( d->m_children );
     for (; childIt.current(); ++childIt )
-        disconnect( childIt.current(), TQT_SIGNAL( destroyed() ),
-                    this, TQT_SLOT( slotChildDestroyed() ) );
+        disconnect( childIt.current(), TQ_SIGNAL( destroyed() ),
+                    this, TQ_SLOT( slotChildDestroyed() ) );
 
     // Tell our views that the document is already destroyed and
     // that they shouldn't try to access it.
@@ -544,7 +544,7 @@ void KoDocument::slotAutoSave()
 {
     if ( isModified() && d->modifiedAfterAutosave && !d->m_bLoading )
     {
-        connect( this, TQT_SIGNAL( sigProgress( int ) ), shells().current(), TQT_SLOT( slotProgress( int ) ) );
+        connect( this, TQ_SIGNAL( sigProgress( int ) ), shells().current(), TQ_SLOT( slotProgress( int ) ) );
         emit sigStatusBarMessage( i18n("Autosaving...") );
         d->m_autosaving = true;
         bool ret = saveNativeFormat( autoSaveFile( m_file ) );
@@ -555,7 +555,7 @@ void KoDocument::slotAutoSave()
         }
         d->m_autosaving = false;
         emit sigClearStatusBarMessage();
-        disconnect( this, TQT_SIGNAL( sigProgress( int ) ), shells().current(), TQT_SLOT( slotProgress( int ) ) );
+        disconnect( this, TQ_SIGNAL( sigProgress( int ) ), shells().current(), TQ_SLOT( slotProgress( int ) ) );
         if ( !ret )
             emit sigStatusBarMessage( i18n("Error during autosave! Partition full?") );
     }
@@ -657,10 +657,10 @@ void KoDocument::insertChild( KoDocumentChild *child )
 
     d->m_children.append( child );
 
-    connect( child, TQT_SIGNAL( changed( KoChild * ) ),
-             this, TQT_SLOT( slotChildChanged( KoChild * ) ) );
-    connect( child, TQT_SIGNAL( destroyed() ),
-             this, TQT_SLOT( slotChildDestroyed() ) );
+    connect( child, TQ_SIGNAL( changed( KoChild * ) ),
+             this, TQ_SLOT( slotChildChanged( KoChild * ) ) );
+    connect( child, TQ_SIGNAL( destroyed() ),
+             this, TQ_SLOT( slotChildDestroyed() ) );
 
     // It may be that insertChild is called without the KoDocumentChild
     // having a KoDocument attached, yet. This happens for example
@@ -978,7 +978,7 @@ bool KoDocument::saveNativeFormat( const TQString & file )
         TQFile f( file );
         if ( f.open( IO_WriteOnly | IO_Translate ) )
         {
-            bool success = saveToStream( TQT_TQIODEVICE(&f) );
+            bool success = saveToStream( &f );
             f.close();
             return success;
         }
@@ -992,7 +992,7 @@ bool KoDocument::saveNativeFormat( const TQString & file )
     TQCString mimeType = d->outputMimeType;
     TQCString nativeOasisMime = nativeOasisMimeType();
     bool oasis = !mimeType.isEmpty() && ( mimeType == nativeOasisMime || mimeType == nativeOasisMime + "-template" );
-    // TODO: use std::auto_ptr or create store on stack [needs API fixing],
+    // TODO: use std::unique_ptr or create store on stack [needs API fixing],
     // to remove all the 'delete store' in all the branches
     KoStore* store = KoStore::createStore( file, KoStore::Write, mimeType, backend );
     if ( store->bad() )
@@ -1185,7 +1185,7 @@ bool KoDocument::saveToStore( KoStore* _store, const TQString & _path )
 bool KoDocument::saveOasisPreview( KoStore* store, KoXmlWriter* manifestWriter )
 {
     const TQPixmap pix = generatePreview( TQSize( 128, 128 ) );
-    TQImage preview ( pix.convertToImage().convertDepth( 32, Qt::ColorOnly ) );
+    TQImage preview ( pix.convertToImage().convertDepth( 32, TQt::ColorOnly ) );
     if ( !preview.hasAlphaBuffer() )
     {
         preview.setAlphaBuffer( true );
@@ -1206,7 +1206,7 @@ bool KoDocument::savePreview( KoStore* store )
 {
     TQPixmap pix = generatePreview(TQSize(256, 256));
     // Reducing to 8bpp reduces file sizes quite a lot.
-    const TQImage preview ( pix.convertToImage().convertDepth( 8, Qt::AvoidDither | Qt::DiffuseDither) );
+    const TQImage preview ( pix.convertToImage().convertDepth( 8, TQt::AvoidDither | TQt::DiffuseDither) );
     KoStoreDevice io ( store );
     if ( !io.open( IO_WriteOnly ) )
         return false;
@@ -1298,7 +1298,7 @@ bool KoDocument::checkAutoSaveFile()
     if ( TQFile::exists( asf ) )
     {
         TQDateTime date = TQFileInfo(asf).lastModified();
-        TQString dateStr = date.toString(Qt::LocalDate);
+        TQString dateStr = date.toString(TQt::LocalDate);
         int res = KMessageBox::warningYesNoCancel(
             0, i18n( "An autosaved file for an unnamed document exists in %1.\nThis file is dated %2\nDo you want to open it?" )
             .arg(asf, dateStr) );
@@ -1727,7 +1727,7 @@ bool KoDocument::loadNativeFormat( const TQString & file )
         bool res;
         if ( doc.setContent( &in, true, &errorMsg, &errorLine, &errorColumn ) )
         {
-            res = loadXML( TQT_TQIODEVICE(&in), doc );
+            res = loadXML( &in, doc );
             if ( res )
                 res = completeLoading( 0L );
         }
@@ -2576,7 +2576,7 @@ void KoDocument::openExistingFile( const TQString& file )
     setModified( false );
 
     if( ok )
-        TQTimer::singleShot( 0, this, TQT_SLOT( deleteOpenPane() ) );
+        TQTimer::singleShot( 0, this, TQ_SLOT( deleteOpenPane() ) );
 }
 
 void KoDocument::openTemplate( const TQString& file )
@@ -2611,14 +2611,14 @@ KoOpenPane* KoDocument::createOpenPane( TQWidget* parent, TDEInstance* instance,
     TQWidget *customDoc = createCustomDocumentWidget(openPane);
     if(customDoc) {
         openPane->setCustomDocumentWidget( customDoc );
-        connect( customDoc, TQT_SIGNAL( documentSelected() ), this, TQT_SLOT( startCustomDocument() ) );
+        connect( customDoc, TQ_SIGNAL( documentSelected() ), this, TQ_SLOT( startCustomDocument() ) );
     }
     openPane->show();
 
-    connect( openPane, TQT_SIGNAL( openExistingFile( const TQString& ) ),
-             this, TQT_SLOT( openExistingFile( const TQString& ) ) );
-    connect( openPane, TQT_SIGNAL( openTemplate( const TQString& ) ),
-             this, TQT_SLOT( openTemplate( const TQString& ) ) );
+    connect( openPane, TQ_SIGNAL( openExistingFile( const TQString& ) ),
+             this, TQ_SLOT( openExistingFile( const TQString& ) ) );
+    connect( openPane, TQ_SIGNAL( openTemplate( const TQString& ) ),
+             this, TQ_SLOT( openTemplate( const TQString& ) ) );
 
     return openPane;
 }
@@ -2637,7 +2637,7 @@ void KoDocument::deleteOpenPane()
 {
     if( d->m_startUpWidget ) {
         d->m_startUpWidget->hide();
-        TQTimer::singleShot(1000, this, TQT_SLOT(deleteOpenPaneDelayed()));
+        TQTimer::singleShot(1000, this, TQ_SLOT(deleteOpenPaneDelayed()));
 
         shells().getFirst()->factory()->container("mainToolBar", shells().getFirst())->show();
         shells().getFirst()->setRootDocument( this );
@@ -2663,7 +2663,7 @@ bool KoDocument::showEmbedInitDialog(TQWidget* parent)
     pane->layout()->setMargin(0);
     dlg.setMainWidget(pane);
     dlg.setInitialSize(dlg.configDialogSize("EmbedInitDialog"));
-    connect(this, TQT_SIGNAL(closeEmbedInitDialog()), &dlg, TQT_SLOT(slotOk()));
+    connect(this, TQ_SIGNAL(closeEmbedInitDialog()), &dlg, TQ_SLOT(slotOk()));
 
     bool ok = dlg.exec() == TQDialog::Accepted;
 
