@@ -50,7 +50,7 @@ namespace KParts
  */
 class KOFFICECORE_EXPORT KoMainWindow : public KParts::MainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
