@@ -114,20 +114,20 @@ KoView::KoView( KoDocument *document, TQWidget *parent, const char *name )
   //kdDebug(30003) << "KoView::KoView " << this << endl;
   d = new KoViewPrivate;
   d->m_doc = document;
-  KParts::PartBase::setPartObject( TQT_TQOBJECT(this) );
+  KParts::PartBase::setPartObject( this );
 
   setFocusPolicy( TQWidget::StrongFocus );
 
   setMouseTracking( true );
 
-  connect( d->m_doc, TQT_SIGNAL( childChanged( KoDocumentChild * ) ),
-           this, TQT_SLOT( slotChildChanged( KoDocumentChild * ) ) );
+  connect( d->m_doc, TQ_SIGNAL( childChanged( KoDocumentChild * ) ),
+           this, TQ_SLOT( slotChildChanged( KoDocumentChild * ) ) );
 
-  connect( d->m_doc, TQT_SIGNAL( sigBeginOperation() ),
-           this, TQT_SLOT( beginOperation() ) );
+  connect( d->m_doc, TQ_SIGNAL( sigBeginOperation() ),
+           this, TQ_SLOT( beginOperation() ) );
 
-  connect( d->m_doc, TQT_SIGNAL( sigEndOperation() ),
-           this, TQT_SLOT( endOperation() ) );
+  connect( d->m_doc, TQ_SIGNAL( sigEndOperation() ),
+           this, TQ_SLOT( endOperation() ) );
 
 
   actionCollection()->setWidget( this );
@@ -145,20 +145,20 @@ KoView::KoView( KoDocument *document, TQWidget *parent, const char *name )
   if ( sb ) // No statusbar in e.g. konqueror
   {
       coll->setHighlightingEnabled( true );
-      connect( coll, TQT_SIGNAL( actionStatusText( const TQString & ) ),
-               this, TQT_SLOT( slotActionStatusText( const TQString & ) ) );
-      connect( coll, TQT_SIGNAL( clearStatusText() ),
-               this, TQT_SLOT( slotClearStatusText() ) );
+      connect( coll, TQ_SIGNAL( actionStatusText( const TQString & ) ),
+               this, TQ_SLOT( slotActionStatusText( const TQString & ) ) );
+      connect( coll, TQ_SIGNAL( clearStatusText() ),
+               this, TQ_SLOT( slotClearStatusText() ) );
 
-      connect( d->m_doc, TQT_SIGNAL( sigStatusBarMessage( const TQString& ) ),
-               this, TQT_SLOT( slotActionStatusText( const TQString& ) ) );
-      connect( d->m_doc, TQT_SIGNAL( sigClearStatusBarMessage() ),
-               this, TQT_SLOT( slotClearStatusText() ) );
+      connect( d->m_doc, TQ_SIGNAL( sigStatusBarMessage( const TQString& ) ),
+               this, TQ_SLOT( slotActionStatusText( const TQString& ) ) );
+      connect( d->m_doc, TQ_SIGNAL( sigClearStatusBarMessage() ),
+               this, TQ_SLOT( slotClearStatusText() ) );
   }
   d->m_doc->setCurrent();
 
   d->m_scrollTimer = new TQTimer( this );
-  connect (d->m_scrollTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotAutoScroll() ) );
+  connect (d->m_scrollTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAutoScroll() ) );
 }
 
 KoView::~KoView()
@@ -533,7 +533,7 @@ void KoView::slotChildActivated( bool a )
   // Is the new active view a child of this one ?
   // In this case we may not delete!
   //  TQObject *n = d->m_manager->activeWidget();
-  TQObject *n = TQT_TQOBJECT(activeWidget);
+  TQObject *n = activeWidget;
   while( n )
     if ( n == (TQObject *)view )
       return;
@@ -627,7 +627,7 @@ void KoView::slotAutoScroll(  )
 
 void KoView::setupGlobalActions() {
     actionNewView = new TDEAction( i18n( "&New View" ), "window-new", 0,
-        TQT_TQOBJECT(this), TQT_SLOT( newView() ),
+        this, TQ_SLOT( newView() ),
         actionCollection(), "view_newview" );
 }
 
@@ -763,8 +763,8 @@ KoViewChild::KoViewChild( KoDocumentChild *child, KoView *_parentView )
   // Setting the frameGeometry is done in setInitialFrameGeometry, which is
   // also called right after activation.
 
-  connect( view, TQT_SIGNAL( activated( bool ) ),
-           parentView(), TQT_SLOT( slotChildActivated( bool ) ) );
+  connect( view, TQ_SIGNAL( activated( bool ) ),
+           parentView(), TQ_SLOT( slotChildActivated( bool ) ) );
 }
 
 KoViewChild::~KoViewChild()
@@ -852,10 +852,10 @@ void KoViewChild::setInitialFrameGeometry()
     kdDebug() << k_funcinfo << endl;
 
     // Connect only now, so that the GUI building doesn't move us around.
-    connect( m_frame, TQT_SIGNAL( geometryChanged() ),
-             this, TQT_SLOT( slotFrameGeometryChanged() ) );
-    connect( m_child, TQT_SIGNAL( changed( KoChild * ) ),
-             this, TQT_SLOT( slotDocGeometryChanged() ) );
+    connect( m_frame, TQ_SIGNAL( geometryChanged() ),
+             this, TQ_SLOT( slotFrameGeometryChanged() ) );
+    connect( m_child, TQ_SIGNAL( changed( KoChild * ) ),
+             this, TQ_SLOT( slotDocGeometryChanged() ) );
 
     // Set frameGeometry from childGeometry
     slotDocGeometryChanged();
