@@ -38,10 +38,10 @@ KoPartSelectDia::KoPartSelectDia( TQWidget* parent, const char* name ) :
     listview->setAllColumnsShowFocus( TRUE );
     listview->setShowSortIndicator( TRUE );
     setMainWidget( listview );
-    connect( listview, TQT_SIGNAL( doubleClicked( TQListViewItem * ) ),
-	     this, TQT_SLOT( slotOk() ) );
-    connect( listview, TQT_SIGNAL( selectionChanged( TQListViewItem * ) ),
-	     this, TQT_SLOT( selectionChanged( TQListViewItem * ) ) );
+    connect( listview, TQ_SIGNAL( doubleClicked( TQListViewItem * ) ),
+	     this, TQ_SLOT( slotOk() ) );
+    connect( listview, TQ_SIGNAL( selectionChanged( TQListViewItem * ) ),
+	     this, TQ_SLOT( selectionChanged( TQListViewItem * ) ) );
 
     // Query for documents
     m_lstEntries = KoDocumentEntry::query();
