@@ -335,8 +335,8 @@ void KoTemplateChooseDia::setupRecentDialog(TQWidget * widgetbase, TQGridLayout
         d->m_instance->config()->setGroup( oldGroup );
         d->m_recent->showPreviews();
 
-	connect(d->m_recent, TQT_SIGNAL( doubleClicked ( TQIconViewItem * ) ),
-			this, TQT_SLOT( recentSelected( TQIconViewItem * ) ) );
+	connect(d->m_recent, TQ_SIGNAL( doubleClicked ( TQIconViewItem * ) ),
+			this, TQ_SLOT( recentSelected( TQIconViewItem * ) ) );
 
 }
 
@@ -377,11 +377,11 @@ void KoTemplateChooseDia::setupFileDialog(TQWidget * widgetbase, TQGridLayout *
     }
     d->m_filedialog->setMimeFilter( mimeFilter );
 
-    connect(d->m_filedialog, TQT_SIGNAL(  okClicked() ),
-	    this, TQT_SLOT (  slotOk() ));
+    connect(d->m_filedialog, TQ_SIGNAL(  okClicked() ),
+	    this, TQ_SLOT (  slotOk() ));
 
-    connect(d->m_filedialog, TQT_SIGNAL( cancelClicked() ),
-	    this, TQT_SLOT (  slotCancel() ));
+    connect(d->m_filedialog, TQ_SIGNAL( cancelClicked() ),
+	    this, TQ_SLOT (  slotCancel() ));
 
 }
 
@@ -445,11 +445,11 @@ void KoTemplateChooseDia::setupTemplateDialog(TQWidget * widgetbase, TQGridLayou
 	canvas->sort();
 	canvas->setSelectionMode(TQIconView::Single);
 
-	connect( canvas, TQT_SIGNAL( clicked ( TQIconViewItem * ) ),
-		this, TQT_SLOT( currentChanged( TQIconViewItem * ) ) );
+	connect( canvas, TQ_SIGNAL( clicked ( TQIconViewItem * ) ),
+		this, TQ_SLOT( currentChanged( TQIconViewItem * ) ) );
 
-	connect( canvas, TQT_SIGNAL( doubleClicked( TQIconViewItem * ) ),
-		this, TQT_SLOT( chosen(TQIconViewItem *) ) );
+	connect( canvas, TQ_SIGNAL( doubleClicked( TQIconViewItem * ) ),
+		this, TQ_SLOT( chosen(TQIconViewItem *) ) );
 
 	entriesnumber++;
     }
