@@ -42,7 +42,7 @@ KoHSVWidget::KoHSVWidget(TQWidget *parent, const char *name) : super(parent, nam
     TQGridLayout *mGrid = new TQGridLayout(this, 5, 7, 5, 2);
     m_colorwheel = new KoColorWheel(this);
     m_colorwheel->setFixedSize( 120, 120);
-    m_VSelector = new KValueSelector(Qt::Vertical, this);
+    m_VSelector = new KValueSelector(TQt::Vertical, this);
     m_VSelector-> setFixedSize( 30, 120);
 
     /* setup slider labels */
@@ -84,17 +84,17 @@ KoHSVWidget::KoHSVWidget(TQWidget *parent, const char *name) : super(parent, nam
     mGrid->addMultiCellWidget(m_VSelector, 0, 3, 5, 5);
 
 
-    connect(m_ColorButton, TQT_SIGNAL(fgChanged(const TQColor &)), this, TQT_SLOT(slotFGColorSelected(const TQColor &)));
-    connect(m_ColorButton, TQT_SIGNAL(bgChanged(const TQColor &)), this, TQT_SLOT(slotBGColorSelected(const TQColor &)));
-    connect(m_ColorButton, TQT_SIGNAL(currentChanged(KDualColorButton::DualColor)), this, TQT_SLOT(currentChanged(KDualColorButton::DualColor)));
+    connect(m_ColorButton, TQ_SIGNAL(fgChanged(const TQColor &)), this, TQ_SLOT(slotFGColorSelected(const TQColor &)));
+    connect(m_ColorButton, TQ_SIGNAL(bgChanged(const TQColor &)), this, TQ_SLOT(slotBGColorSelected(const TQColor &)));
+    connect(m_ColorButton, TQ_SIGNAL(currentChanged(KDualColorButton::DualColor)), this, TQ_SLOT(currentChanged(KDualColorButton::DualColor)));
 
-    connect(m_VSelector, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotVChanged(int)));
-    connect(m_colorwheel, TQT_SIGNAL(valueChanged(const KoColor&)), this, TQT_SLOT(slotWheelChanged(const KoColor&)));
+    connect(m_VSelector, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotVChanged(int)));
+    connect(m_colorwheel, TQ_SIGNAL(valueChanged(const KoColor&)), this, TQ_SLOT(slotWheelChanged(const KoColor&)));
 
     /* connect spin box */
-    connect(mHIn, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotHChanged(int)));
-    connect(mSIn, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotSChanged(int)));
-    connect(mVIn, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotVChanged(int)));
+    connect(mHIn, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotHChanged(int)));
+    connect(mSIn, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotSChanged(int)));
+    connect(mVIn, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotVChanged(int)));
 
     //setFixedSize(mGrid -> minimumSize());
     m_autovalue = true; // So on the initial selection of h or v, s gets set to 255.
@@ -181,9 +181,9 @@ void KoHSVWidget::setBgColor(const TQColor & c)
 void KoHSVWidget::changedFgColor()
 {
     //kdDebug() << "ChangedFgColor\n";
-    disconnect(m_ColorButton, TQT_SIGNAL(fgChanged(const TQColor &)), this, TQT_SLOT(slotFGColorSelected(const TQColor &)));
+    disconnect(m_ColorButton, TQ_SIGNAL(fgChanged(const TQColor &)), this, TQ_SLOT(slotFGColorSelected(const TQColor &)));
     m_ColorButton->setForeground( m_fgColor.color() );
-    connect(m_ColorButton, TQT_SIGNAL(fgChanged(const TQColor &)), this, TQT_SLOT(slotFGColorSelected(const TQColor &)));
+    connect(m_ColorButton, TQ_SIGNAL(fgChanged(const TQColor &)), this, TQ_SLOT(slotFGColorSelected(const TQColor &)));
 
     update( m_fgColor, m_bgColor);
 
@@ -193,9 +193,9 @@ void KoHSVWidget::changedFgColor()
 void KoHSVWidget::changedBgColor()
 {
     //kdDebug() << "changedBgColor()\n";
-    disconnect(m_ColorButton, TQT_SIGNAL(bgChanged(const TQColor &)), this, TQT_SLOT(slotBGColorSelected(const TQColor &)));
+    disconnect(m_ColorButton, TQ_SIGNAL(bgChanged(const TQColor &)), this, TQ_SLOT(slotBGColorSelected(const TQColor &)));
     m_ColorButton->setBackground( m_bgColor.color() );
-    connect(m_ColorButton, TQT_SIGNAL(bgChanged(const TQColor &)), this, TQT_SLOT(slotBGColorSelected(const TQColor &)));
+    connect(m_ColorButton, TQ_SIGNAL(bgChanged(const TQColor &)), this, TQ_SLOT(slotBGColorSelected(const TQColor &)));
 
     update(m_fgColor, m_bgColor );
 
