@@ -34,7 +34,7 @@ KoChangeCaseDia::KoChangeCaseDia( TQWidget *parent, const char *name )
     setCaption( i18n("Change Case") );
     TQVBox *page = makeVBoxMainWidget();
 
-    TQButtonGroup *grp = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Case" ),page );
+    TQButtonGroup *grp = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Case" ),page );
     grp->setRadioButtonExclusive( TRUE );
     grp->layout();
     m_upperCase=new TQRadioButton( i18n("&Uppercase"), grp );
