@@ -71,7 +71,7 @@ KoCounterStyleWidget::KoCounterStyleWidget( bool displayDepth, bool onlyStyleTyp
     lstStyle = new TQListBox( gStyle, "styleListBox" );
     grid->addMultiCellWidget( lstStyle, 1, 11, 0, 0);
     fillStyleCombo();
-    connect( lstStyle, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( numStyleChanged() ) );
+    connect( lstStyle, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( numStyleChanged() ) );
 
 
     TQLabel *lPrefix = new TQLabel( gStyle, "lPrefix" );
@@ -116,7 +116,7 @@ KoCounterStyleWidget::KoCounterStyleWidget( bool displayDepth, bool onlyStyleTyp
     bCustom = new TQPushButton( "", gStyle, "bCustom" );
     lCustom->setBuddy( bCustom );
     customCharBox->addWidget( bCustom );
-    connect( bCustom, TQT_SIGNAL( clicked() ), this, TQT_SLOT( selectCustomBullet() ) );
+    connect( bCustom, TQ_SIGNAL( clicked() ), this, TQ_SLOT( selectCustomBullet() ) );
 
     TQSpacerItem* spacer_2 = new TQSpacerItem( 0, 0, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
     customCharBox->addItem( spacer_2 );
@@ -166,14 +166,14 @@ KoCounterStyleWidget::KoCounterStyleWidget( bool displayDepth, bool onlyStyleTyp
     }
 
 
-    connect( cbRestart, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( restartChanged(bool) ) );
+    connect( cbRestart, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( restartChanged(bool) ) );
 
-    connect( sSuffix, TQT_SIGNAL( textChanged (const TQString &) ), this, TQT_SLOT( suffixChanged(const TQString &) ) );
-    connect( sPrefix, TQT_SIGNAL( textChanged (const TQString &) ), this, TQT_SLOT( prefixChanged(const TQString &) ) );
-    connect( spnStart, TQT_SIGNAL( valueChanged (int) ), this, TQT_SLOT( startChanged(int) ) );
-    connect( spnDepth, TQT_SIGNAL( valueChanged (int) ), this, TQT_SLOT( depthChanged(int) ) );
-    connect( spnDisplayLevels, TQT_SIGNAL( valueChanged (int) ), this, TQT_SLOT( displayLevelsChanged(int) ) );
-    connect( cbAlignment, TQT_SIGNAL( activated (const TQString&) ), this, TQT_SLOT( alignmentChanged(const TQString&) ) );
+    connect( sSuffix, TQ_SIGNAL( textChanged (const TQString &) ), this, TQ_SLOT( suffixChanged(const TQString &) ) );
+    connect( sPrefix, TQ_SIGNAL( textChanged (const TQString &) ), this, TQ_SLOT( prefixChanged(const TQString &) ) );
+    connect( spnStart, TQ_SIGNAL( valueChanged (int) ), this, TQ_SLOT( startChanged(int) ) );
+    connect( spnDepth, TQ_SIGNAL( valueChanged (int) ), this, TQ_SLOT( depthChanged(int) ) );
+    connect( spnDisplayLevels, TQ_SIGNAL( valueChanged (int) ), this, TQ_SLOT( displayLevelsChanged(int) ) );
+    connect( cbAlignment, TQ_SIGNAL( activated (const TQString&) ), this, TQ_SLOT( alignmentChanged(const TQString&) ) );
     noSignals = false;
     if ( disableAll )
     {
@@ -747,22 +747,22 @@ TQPen KoBorderPreview::setBorderPen( KoBorder _brd )
 
     switch ( _brd.getStyle() ) {
     case KoBorder::SOLID:
-        pen.setStyle( Qt::SolidLine );
+        pen.setStyle( TQt::SolidLine );
         break;
     case KoBorder::DASH:
-        pen.setStyle( Qt::DashLine );
+        pen.setStyle( TQt::DashLine );
         break;
     case KoBorder::DOT:
-        pen.setStyle( Qt::DotLine );
+        pen.setStyle( TQt::DotLine );
         break;
     case KoBorder::DASH_DOT:
-        pen.setStyle( Qt::DashDotLine );
+        pen.setStyle( TQt::DashDotLine );
         break;
     case KoBorder::DASH_DOT_DOT:
-        pen.setStyle( Qt::DashDotDotLine );
+        pen.setStyle( TQt::DashDotDotLine );
         break;
     case KoBorder::DOUBLE_LINE:
-        pen.setStyle( Qt::SolidLine );
+        pen.setStyle( TQt::SolidLine );
         break;
     }
 
@@ -899,7 +899,7 @@ KoIndentSpacingWidget::KoIndentSpacingWidget( KoUnit::Unit unit,  double _frameW
     eLeft = new KoUnitDoubleSpinBox( indentFrame, 0, 9999, 1, 0.0, m_unit );
     lLeft->setBuddy( eLeft );
     indentGrid->addWidget( eLeft, 1, 1 );
-    connect( eLeft, TQT_SIGNAL( valueChangedPt(double ) ), this, TQT_SLOT( leftChanged( double ) ) );
+    connect( eLeft, TQ_SIGNAL( valueChangedPt(double ) ), this, TQ_SLOT( leftChanged( double ) ) );
 
     TQLabel * lRight = new TQLabel( i18n("&Right:"), indentFrame );
     lRight->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
@@ -908,7 +908,7 @@ KoIndentSpacingWidget::KoIndentSpacingWidget( KoUnit::Unit unit,  double _frameW
     eRight = new KoUnitDoubleSpinBox( indentFrame, 0, 9999, 1, 0.0, m_unit );
     lRight->setBuddy( eRight );
     indentGrid->addWidget( eRight, 2, 1 );
-    connect( eRight, TQT_SIGNAL( valueChangedPt( double ) ), this, TQT_SLOT( rightChanged( double ) ) );
+    connect( eRight, TQ_SIGNAL( valueChangedPt( double ) ), this, TQ_SLOT( rightChanged( double ) ) );
 
     TQLabel * lFirstLine = new TQLabel( i18n("&First line:"), indentFrame );
     lFirstLine->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
@@ -916,7 +916,7 @@ KoIndentSpacingWidget::KoIndentSpacingWidget( KoUnit::Unit unit,  double _frameW
 
     eFirstLine = new KoUnitDoubleSpinBox( indentFrame, -9999, 9999, 1, 0.0, m_unit );
     lFirstLine->setBuddy( eFirstLine );
-    connect( eFirstLine, TQT_SIGNAL( valueChangedPt( double ) ), this, TQT_SLOT( firstChanged( double ) ) );
+    connect( eFirstLine, TQ_SIGNAL( valueChangedPt( double ) ), this, TQ_SLOT( firstChanged( double ) ) );
     indentGrid->addWidget( eFirstLine, 3, 1 );
 
     // grid row spacing
@@ -940,7 +940,7 @@ KoIndentSpacingWidget::KoIndentSpacingWidget( KoUnit::Unit unit,  double _frameW
     cSpacing->insertItem( i18n( "At Least (%1)" ).arg(unitName) );
     cSpacing->insertItem( i18n( "Fixed (%1)").arg(unitName) ); // LS_FIXED
 
-    connect( cSpacing, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( spacingActivated( int ) ) );
+    connect( cSpacing, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( spacingActivated( int ) ) );
     spacingGrid->addWidget( cSpacing, 1, 0 );
 
     sSpacingStack = new TQWidgetStack( spacingFrame );
@@ -948,11 +948,11 @@ KoIndentSpacingWidget::KoIndentSpacingWidget( KoUnit::Unit unit,  double _frameW
     eSpacing = new KoUnitDoubleSpinBox( spacingFrame, 0, 9999, CM_TO_POINT(1),
 					0.0, m_unit );
     eSpacing->setRange( 0, 9999, 1, false);
-    connect( eSpacing, TQT_SIGNAL( valueChanged( double ) ), this, TQT_SLOT( spacingChanged( double ) ) );
+    connect( eSpacing, TQ_SIGNAL( valueChanged( double ) ), this, TQ_SLOT( spacingChanged( double ) ) );
     eSpacingPercent = new KIntNumInput( 100, spacingFrame );
     eSpacingPercent->setRange( 0, 1000, 10, false );
     eSpacingPercent->setSuffix( " %" );
-    connect( eSpacingPercent, TQT_SIGNAL( valueChanged( int ) ), this, TQT_SLOT( spacingChanged( int ) ) );
+    connect( eSpacingPercent, TQ_SIGNAL( valueChanged( int ) ), this, TQ_SLOT( spacingChanged( int ) ) );
     
     sSpacingStack->addWidget( eSpacing );
     sSpacingStack->addWidget( eSpacingPercent );
@@ -977,7 +977,7 @@ KoIndentSpacingWidget::KoIndentSpacingWidget( KoUnit::Unit unit,  double _frameW
 
     eBefore = new KoUnitDoubleSpinBox( pSpaceFrame, 0, 9999, CM_TO_POINT(1), 0.0, m_unit );
     eBefore->setRange( 0 , 9999, 1, false);
-    connect( eBefore, TQT_SIGNAL( valueChanged( double ) ), this, TQT_SLOT( beforeChanged( double ) ) );
+    connect( eBefore, TQ_SIGNAL( valueChanged( double ) ), this, TQ_SLOT( beforeChanged( double ) ) );
     pSpaceGrid->addWidget( eBefore, 1, 1 );
 
     TQLabel * lAfter = new TQLabel( i18n("After:"), pSpaceFrame );
@@ -986,7 +986,7 @@ KoIndentSpacingWidget::KoIndentSpacingWidget( KoUnit::Unit unit,  double _frameW
 
     eAfter = new KoUnitDoubleSpinBox( pSpaceFrame, 0, 9999, 1, 0.0, m_unit );
     eAfter->setRange( 0, 9999, 1, false);
-    connect( eAfter, TQT_SIGNAL( valueChanged( double ) ), this, TQT_SLOT( afterChanged( double ) ) );
+    connect( eAfter, TQ_SIGNAL( valueChanged( double ) ), this, TQ_SLOT( afterChanged( double ) ) );
     pSpaceGrid->addWidget( eAfter, 2, 1 );
 
     // grid row spacing
@@ -1211,16 +1211,16 @@ KoParagAlignWidget::KoParagAlignWidget( bool breakLine, TQWidget * parent, const
     TQVGroupBox * AlignGroup = new TQVGroupBox( i18n( "Alignment" ), this );
 
     rLeft = new TQRadioButton( i18n( "&Left" ), AlignGroup );
-    connect( rLeft, TQT_SIGNAL( clicked() ), this, TQT_SLOT( alignLeft() ) );
+    connect( rLeft, TQ_SIGNAL( clicked() ), this, TQ_SLOT( alignLeft() ) );
 
     rCenter = new TQRadioButton( i18n( "C&enter" ), AlignGroup );
-    connect( rCenter, TQT_SIGNAL( clicked() ), this, TQT_SLOT( alignCenter() ) );
+    connect( rCenter, TQ_SIGNAL( clicked() ), this, TQ_SLOT( alignCenter() ) );
 
     rRight = new TQRadioButton( i18n( "&Right" ), AlignGroup );
-    connect( rRight, TQT_SIGNAL( clicked() ), this, TQT_SLOT( alignRight() ) );
+    connect( rRight, TQ_SIGNAL( clicked() ), this, TQ_SLOT( alignRight() ) );
 
     rJustify = new TQRadioButton( i18n( "&Justify" ), AlignGroup );
-    connect( rJustify, TQT_SIGNAL( clicked() ), this, TQT_SLOT( alignJustify() ) );
+    connect( rJustify, TQ_SIGNAL( clicked() ), this, TQ_SLOT( alignJustify() ) );
 
     clearAligns();
     rLeft->setChecked( true );
@@ -1376,23 +1376,23 @@ KoParagDecorationWidget::KoParagDecorationWidget( TQWidget * parent,
         wDeco->cbBorderWidth->insertItem(TQString::number(i));
 
     // Setup the border toggle buttons, and merge checkbox
-    connect( wDeco->bBorderLeft, TQT_SIGNAL( toggled( bool ) ),
-             this, TQT_SLOT( brdLeftToggled( bool ) ) );
-    connect( wDeco->bBorderRight, TQT_SIGNAL( toggled( bool ) ),
-             this, TQT_SLOT( brdRightToggled( bool ) ) );
-    connect( wDeco->bBorderTop, TQT_SIGNAL( toggled( bool ) ),
-             this, TQT_SLOT( brdTopToggled( bool ) ) );
-    connect( wDeco->bBorderBottom, TQT_SIGNAL( toggled( bool ) ),
-             this, TQT_SLOT( brdBottomToggled( bool ) ) );
-    connect( wDeco->cbJoinBorder, TQT_SIGNAL( toggled( bool ) ),
-             this, TQT_SLOT( brdJoinToggled( bool ) ) );
+    connect( wDeco->bBorderLeft, TQ_SIGNAL( toggled( bool ) ),
+             this, TQ_SLOT( brdLeftToggled( bool ) ) );
+    connect( wDeco->bBorderRight, TQ_SIGNAL( toggled( bool ) ),
+             this, TQ_SLOT( brdRightToggled( bool ) ) );
+    connect( wDeco->bBorderTop, TQ_SIGNAL( toggled( bool ) ),
+             this, TQ_SLOT( brdTopToggled( bool ) ) );
+    connect( wDeco->bBorderBottom, TQ_SIGNAL( toggled( bool ) ),
+             this, TQ_SLOT( brdBottomToggled( bool ) ) );
+    connect( wDeco->cbJoinBorder, TQ_SIGNAL( toggled( bool ) ),
+             this, TQ_SLOT( brdJoinToggled( bool ) ) );
 
     // Set up Border preview widget
     wPreview  = new KoBorderPreview( wDeco->borderPreview );
     TQVBoxLayout *previewLayout = new TQVBoxLayout( wDeco->borderPreview );
     previewLayout->addWidget( wPreview );
-    connect( wPreview, TQT_SIGNAL( choosearea(TQMouseEvent * ) ),
-             this, TQT_SLOT( slotPressEvent(TQMouseEvent *) ) );
+    connect( wPreview, TQ_SIGNAL( choosearea(TQMouseEvent * ) ),
+             this, TQ_SLOT( slotPressEvent(TQMouseEvent *) ) );
 }
 
 ///////
@@ -1600,7 +1600,7 @@ KoParagCounterWidget::KoParagCounterWidget( bool disableAll, TQWidget * parent,
 
     gNumbering = new TQButtonGroup( this, "numberingGroup" );
     gNumbering->setTitle( i18n( "Numbering" ) );
-    gNumbering->setColumnLayout(0, Qt::Vertical );
+    gNumbering->setColumnLayout(0, TQt::Vertical );
     gNumbering->layout()->setSpacing( 0 );
     gNumbering->layout()->setMargin( 0 );
     TQHBoxLayout *numberingGroupLayout = new TQHBoxLayout( gNumbering->layout() );
@@ -1625,21 +1625,21 @@ KoParagCounterWidget::KoParagCounterWidget( bool disableAll, TQWidget * parent,
     gNumbering->insert( rChapter , KoParagCounter::NUM_CHAPTER);
     numberingGroupLayout->addWidget( rChapter );
     Form1Layout->addWidget( gNumbering );
-    connect( gNumbering, TQT_SIGNAL( clicked( int ) ), this, TQT_SLOT( numTypeChanged( int ) ) );
+    connect( gNumbering, TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( numTypeChanged( int ) ) );
 
     m_styleWidget = new KoCounterStyleWidget( true, false, disableAll, this );
 
-    connect( m_styleWidget, TQT_SIGNAL( sig_suffixChanged (const TQString &) ), this, TQT_SLOT( suffixChanged(const TQString &) ) );
-    connect( m_styleWidget, TQT_SIGNAL( sig_prefixChanged (const TQString &) ), this, TQT_SLOT( prefixChanged(const TQString &) ) );
-    connect( m_styleWidget, TQT_SIGNAL( sig_startChanged(int) ), this, TQT_SLOT( startChanged(int) ) );
-    connect( m_styleWidget, TQT_SIGNAL( sig_restartChanged(bool) ), this, TQT_SLOT( restartChanged(bool) ) );
-    connect( m_styleWidget, TQT_SIGNAL( sig_depthChanged (int) ), this, TQT_SLOT( depthChanged(int) ) );
-    connect( m_styleWidget, TQT_SIGNAL( sig_displayLevelsChanged (int) ), this, TQT_SLOT( displayLevelsChanged(int) ) );
-    connect( m_styleWidget, TQT_SIGNAL( sig_alignmentChanged (int) ), this, TQT_SLOT( alignmentChanged(int) ) );
-    connect( m_styleWidget, TQT_SIGNAL( changeCustomBullet( const TQString & , TQChar ) ), this, TQT_SLOT( slotChangeCustomBullet( const TQString & , TQChar ) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_suffixChanged (const TQString &) ), this, TQ_SLOT( suffixChanged(const TQString &) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_prefixChanged (const TQString &) ), this, TQ_SLOT( prefixChanged(const TQString &) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_startChanged(int) ), this, TQ_SLOT( startChanged(int) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_restartChanged(bool) ), this, TQ_SLOT( restartChanged(bool) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_depthChanged (int) ), this, TQ_SLOT( depthChanged(int) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_displayLevelsChanged (int) ), this, TQ_SLOT( displayLevelsChanged(int) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_alignmentChanged (int) ), this, TQ_SLOT( alignmentChanged(int) ) );
+    connect( m_styleWidget, TQ_SIGNAL( changeCustomBullet( const TQString & , TQChar ) ), this, TQ_SLOT( slotChangeCustomBullet( const TQString & , TQChar ) ) );
 
-    connect( m_styleWidget, TQT_SIGNAL( sig_numTypeChanged( int ) ), this, TQT_SLOT( numTypeChanged(int ) ) );
-    connect( m_styleWidget, TQT_SIGNAL( changeStyle( KoParagCounter::Style ) ), this, TQT_SLOT( styleChanged (KoParagCounter::Style ) ) );
+    connect( m_styleWidget, TQ_SIGNAL( sig_numTypeChanged( int ) ), this, TQ_SLOT( numTypeChanged(int ) ) );
+    connect( m_styleWidget, TQ_SIGNAL( changeStyle( KoParagCounter::Style ) ), this, TQ_SLOT( styleChanged (KoParagCounter::Style ) ) );
 
     Form1Layout->addWidget( m_styleWidget );
 
@@ -1724,8 +1724,8 @@ KoTabulatorsLineEdit::KoTabulatorsLineEdit( TQWidget *parent, double lower, doub
 
 void KoTabulatorsLineEdit::keyPressEvent ( TQKeyEvent *ke )
 {
-    if( ke->key()  == Qt::Key_Return ||
-        ke->key()  == Qt::Key_Enter )
+    if( ke->key()  == TQt::Key_Return ||
+        ke->key()  == TQt::Key_Enter )
     {
         emit keyReturnPressed();
         return;
@@ -1765,7 +1765,7 @@ KoParagTabulatorsWidget::KoParagTabulatorsWidget( KoUnit::Unit unit, double fram
 
     gPosition = new TQGroupBox( this, "gPosition" );
     gPosition->setTitle( i18n( "Po&sition" ) );
-    gPosition->setColumnLayout(0, Qt::Vertical );
+    gPosition->setColumnLayout(0, TQt::Vertical );
     gPosition->layout()->setSpacing( 0 );
     gPosition->layout()->setMargin( 0 );
     TQVBoxLayout* GroupBox2Layout = new TQVBoxLayout( gPosition->layout() );
@@ -1793,7 +1793,7 @@ KoParagTabulatorsWidget::KoParagTabulatorsWidget( KoUnit::Unit unit, double fram
 
     bgAlign = new TQButtonGroup( this );
     bgAlign->setTitle( i18n( "Alignment" ) );
-    bgAlign->setColumnLayout(0, Qt::Vertical );
+    bgAlign->setColumnLayout(0, TQt::Vertical );
     bgAlign->layout()->setSpacing( 0 );
     bgAlign->layout()->setMargin( 0 );
     TQVBoxLayout* ButtonGroup1Layout = new TQVBoxLayout( bgAlign->layout() );
@@ -1898,16 +1898,16 @@ KoParagTabulatorsWidget::KoParagTabulatorsWidget( KoUnit::Unit unit, double fram
 
     //signal valueChanged passes value which the user see (unlike the value() function)
     //so fromUserValue has to be used in slotTabValueChanged
-    connect(sTabPos,TQT_SIGNAL(valueChanged(double)), this, TQT_SLOT(slotTabValueChanged(double )));
-    connect(sTabPos,TQT_SIGNAL( keyReturnPressed()),this,TQT_SLOT(newClicked()));
-    connect(sAlignChar,TQT_SIGNAL(textChanged( const TQString & )), this, TQT_SLOT(slotAlignCharChanged( const TQString & )));
-    connect(bNew,TQT_SIGNAL(clicked ()),this,TQT_SLOT(newClicked()));
-    connect(bDelete,TQT_SIGNAL(clicked ()),this,TQT_SLOT(deleteClicked()));
-    connect(bDeleteAll,TQT_SIGNAL(clicked ()),this,TQT_SLOT(deleteAllClicked()));
-    connect(bgAlign,TQT_SIGNAL(clicked (int)),this,TQT_SLOT(updateAlign(int)));
-    connect(cFilling,TQT_SIGNAL(activated (int)),this,TQT_SLOT(updateFilling(int)));
-    connect(eWidth,TQT_SIGNAL(valueChangedPt( double ) ),this,TQT_SLOT(updateWidth()));
-    connect(lstTabs,TQT_SIGNAL(highlighted (int)),this,TQT_SLOT(setActiveItem(int)));
+    connect(sTabPos,TQ_SIGNAL(valueChanged(double)), this, TQ_SLOT(slotTabValueChanged(double )));
+    connect(sTabPos,TQ_SIGNAL( keyReturnPressed()),this,TQ_SLOT(newClicked()));
+    connect(sAlignChar,TQ_SIGNAL(textChanged( const TQString & )), this, TQ_SLOT(slotAlignCharChanged( const TQString & )));
+    connect(bNew,TQ_SIGNAL(clicked ()),this,TQ_SLOT(newClicked()));
+    connect(bDelete,TQ_SIGNAL(clicked ()),this,TQ_SLOT(deleteClicked()));
+    connect(bDeleteAll,TQ_SIGNAL(clicked ()),this,TQ_SLOT(deleteAllClicked()));
+    connect(bgAlign,TQ_SIGNAL(clicked (int)),this,TQ_SLOT(updateAlign(int)));
+    connect(cFilling,TQ_SIGNAL(activated (int)),this,TQ_SLOT(updateFilling(int)));
+    connect(eWidth,TQ_SIGNAL(valueChangedPt( double ) ),this,TQ_SLOT(updateWidth()));
+    connect(lstTabs,TQ_SIGNAL(highlighted (int)),this,TQ_SLOT(setActiveItem(int)));
     noSignals=false;
 }
 
@@ -2182,7 +2182,7 @@ KoParagDia::KoParagDia( TQWidget* parent, const char* name,
         m_tabulatorsWidget->layout()->setMargin(0);
     }
 
-    connect( this, TQT_SIGNAL( user1Clicked() ), this, TQT_SLOT(slotReset()));
+    connect( this, TQ_SIGNAL( user1Clicked() ), this, TQ_SLOT(slotReset()));
     setInitialSize( TQSize(630, 500) );
 }
 
