@@ -1243,11 +1243,6 @@ void KoTextString::checkBidi() const
     const KoTextStringChar *end = start + length;
 
     // determines the properties we need for layouting
-#ifdef USE_QT4
-    #warning "KoTextString::checkBidi() for Qt4 partially implemented"
-    printf("[WARNING] KoTextString::checkBidi() partially implemented\n");
-    fflush(stdout);
-#else
     TQTextEngine textEngine( toString(), 0 );
     textEngine.direction = (TQChar::Direction) dir;
     textEngine.itemize(TQTextEngine::SingleLine);
@@ -1286,7 +1281,6 @@ void KoTextString::checkBidi() const
     } else {
 	that->rightToLeft = (textEngine.direction == TQChar::DirR);
     }
-#endif // USE_QT4
 }
 
 TQMemArray<KoTextStringChar> KoTextString::subString( int start, int len ) const
