@@ -67,7 +67,7 @@ KoSearchContextUI::KoSearchContextUI( KoSearchContext *ctx, TQWidget *parent )
 {
     m_bOptionsShown = false;
     m_btnShowOptions = new TQPushButton( i18n("Show Formatting Options"), parent );
-    connect( m_btnShowOptions, TQT_SIGNAL( clicked() ), TQT_SLOT( slotShowOptions() ) );
+    connect( m_btnShowOptions, TQ_SIGNAL( clicked() ), TQ_SLOT( slotShowOptions() ) );
 
     m_grid = new TQGridLayout( m_parent, 1, 1, 0, 6 );
     m_grid->addWidget( m_btnShowOptions, 0, 0 );
@@ -174,30 +174,30 @@ KoFindReplace::KoFindReplace( TQWidget * parent, KoReplaceDia * dialog, const TQ
       m_lastTextObjectHighlighted( 0 )
 {
     connectFind( m_replace );
-    connect( m_replace, TQT_SIGNAL( replace( const TQString &, int , int, int ) ),
-             this, TQT_SLOT( replace( const TQString &, int , int,int ) ) );
+    connect( m_replace, TQ_SIGNAL( replace( const TQString &, int , int, int ) ),
+             this, TQ_SLOT( replace( const TQString &, int , int,int ) ) );
 }
 
 void KoFindReplace::connectFind( KFind* find )
 {
-    connect( find, TQT_SIGNAL( optionsChanged() ),
-             this, TQT_SLOT( optionsChanged() ) );
-    connect( find, TQT_SIGNAL( dialogClosed() ),
-             this, TQT_SLOT( dialogClosed() ) );
+    connect( find, TQ_SIGNAL( optionsChanged() ),
+             this, TQ_SLOT( optionsChanged() ) );
+    connect( find, TQ_SIGNAL( dialogClosed() ),
+             this, TQ_SLOT( dialogClosed() ) );
     // Connect highlight signal to code which handles highlighting
     // of found text.
-    connect( find, TQT_SIGNAL( highlight( const TQString &, int, int ) ),
-             this, TQT_SLOT( highlight( const TQString &, int, int ) ) );
+    connect( find, TQ_SIGNAL( highlight( const TQString &, int, int ) ),
+             this, TQ_SLOT( highlight( const TQString &, int, int ) ) );
     // Connect findNext signal - called when pressing the button in the dialog
-    connect( find, TQT_SIGNAL( findNext() ),
-             this, TQT_SLOT( slotFindNext() ) );
+    connect( find, TQ_SIGNAL( findNext() ),
+             this, TQ_SLOT( slotFindNext() ) );
     m_bInit = true;
     m_currentParagraphModified = false;
     m_matchingIndex = -1;
 
     // Also connect to the textiterator
-    connect( &m_textIterator, TQT_SIGNAL( currentParagraphModified( int, int, int ) ),
-             this, TQT_SLOT( slotCurrentParagraphModified( int, int, int ) ) );
+    connect( &m_textIterator, TQ_SIGNAL( currentParagraphModified( int, int, int ) ),
+             this, TQ_SLOT( slotCurrentParagraphModified( int, int, int ) ) );
 }
 
 KoFindReplace::~KoFindReplace()
@@ -389,16 +389,16 @@ void KoFindReplace::replace( const TQString &text, int matchingIndex,
     TQString rep = text.mid( matchingIndex, replacementLength );
 
     // Don't let the replacement set the paragraph to "modified by user"
-    disconnect( &m_textIterator, TQT_SIGNAL( currentParagraphModified( int, int, int ) ),
-                this, TQT_SLOT( slotCurrentParagraphModified( int, int, int ) ) );
+    disconnect( &m_textIterator, TQ_SIGNAL( currentParagraphModified( int, int, int ) ),
+                this, TQ_SLOT( slotCurrentParagraphModified( int, int, int ) ) );
 
     KCommand *cmd = currentTextObj->replaceSelectionCommand(
         &cursor, rep, TQString(),
         KoTextDocument::HighlightSelection,
         repaint ? KoTextObject::DefaultInsertFlags : KoTextObject::DoNotRepaint );
 
-    connect( &m_textIterator, TQT_SIGNAL( currentParagraphModified( int, int, int ) ),
-             this, TQT_SLOT( slotCurrentParagraphModified( int, int, int ) ) );
+    connect( &m_textIterator, TQ_SIGNAL( currentParagraphModified( int, int, int ) ),
+             this, TQ_SLOT( slotCurrentParagraphModified( int, int, int ) ) );
 
     if( cmd )
         macroCommand()->addCommand(cmd);
@@ -549,8 +549,8 @@ KoFormatDia::KoFormatDia( TQWidget* parent, const TQString & _caption, KoSearchC
     setButtonText( KDialogBase::User1, i18n("Reset") );
     setButtonText( KDialogBase::User2, i18n("Clear") );
 
-    connect( this, TQT_SIGNAL( user1Clicked() ), this, TQT_SLOT(slotReset()));
-    connect( this, TQT_SIGNAL( user2Clicked() ), this, TQT_SLOT(slotClear()));
+    connect( this, TQ_SIGNAL( user1Clicked() ), this, TQ_SLOT(slotReset()));
+    connect( this, TQ_SIGNAL( user2Clicked() ), this, TQ_SLOT(slotClear()));
 
     TQGridLayout *m_grid = new TQGridLayout( page, 15, 2, 0, 6 );
     m_checkFamily = new TQCheckBox( i18n( "Family:" ),page  );
@@ -603,25 +603,25 @@ KoFormatDia::KoFormatDia( TQWidget* parent, const TQString & _caption, KoSearchC
 
 
 
-    TQButtonGroup *grpBold = new TQButtonGroup( 1, Qt::Vertical, page );
+    TQButtonGroup *grpBold = new TQButtonGroup( 1, TQt::Vertical, page );
     grpBold->setRadioButtonExclusive( TRUE );
     grpBold->layout();
     m_boldYes=new TQRadioButton( i18n("Yes"), grpBold );
     m_boldNo=new TQRadioButton( i18n("No"), grpBold );
 
-    TQButtonGroup *grpItalic = new TQButtonGroup( 1, Qt::Vertical, page );
+    TQButtonGroup *grpItalic = new TQButtonGroup( 1, TQt::Vertical, page );
     grpItalic->setRadioButtonExclusive( TRUE );
     grpItalic->layout();
     m_italicYes=new TQRadioButton( i18n("Yes"), grpItalic );
     m_italicNo=new TQRadioButton( i18n("No"), grpItalic );
 
-    TQButtonGroup *grpShadow = new TQButtonGroup( 1, Qt::Vertical, page );
+    TQButtonGroup *grpShadow = new TQButtonGroup( 1, TQt::Vertical, page );
     grpShadow->setRadioButtonExclusive( TRUE );
     grpShadow->layout();
     m_shadowYes=new TQRadioButton( i18n("Yes"), grpShadow );
     m_shadowNo=new TQRadioButton( i18n("No"), grpShadow );
 
-    TQButtonGroup *grpWordByWord = new TQButtonGroup( 1, Qt::Vertical, page );
+    TQButtonGroup *grpWordByWord = new TQButtonGroup( 1, TQt::Vertical, page );
     grpWordByWord->setRadioButtonExclusive( TRUE );
     grpWordByWord->layout();
     m_wordByWordYes=new TQRadioButton( i18n("Yes"), grpWordByWord );
@@ -670,29 +670,29 @@ KoFormatDia::KoFormatDia( TQWidget* parent, const TQString & _caption, KoSearchC
     m_grid->addMultiCellWidget( tmpSep, 14, 14, 0, 1 );
 
     // signals and slots connections
-    TQObject::connect( m_checkFamily, TQT_SIGNAL( toggled( bool ) ), m_familyItem, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkSize, TQT_SIGNAL( toggled( bool ) ), m_sizeItem, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkColor, TQT_SIGNAL( toggled( bool ) ), m_colorItem, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkBgColor, TQT_SIGNAL( toggled( bool ) ), m_bgColorItem, TQT_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkFamily, TQ_SIGNAL( toggled( bool ) ), m_familyItem, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkSize, TQ_SIGNAL( toggled( bool ) ), m_sizeItem, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkColor, TQ_SIGNAL( toggled( bool ) ), m_colorItem, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkBgColor, TQ_SIGNAL( toggled( bool ) ), m_bgColorItem, TQ_SLOT( setEnabled( bool ) ) );
 
-    TQObject::connect( m_checkBold, TQT_SIGNAL( toggled( bool ) ), m_boldYes, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkItalic, TQT_SIGNAL( toggled( bool ) ), m_italicYes, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkStrikeOut, TQT_SIGNAL( toggled( bool ) ), m_strikeOutItem, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkShadow, TQT_SIGNAL( toggled( bool ) ), m_shadowYes, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkWordByWord, TQT_SIGNAL( toggled( bool ) ), m_wordByWordYes, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkFontAttribute, TQT_SIGNAL( toggled( bool ) ), m_fontAttributeItem, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkLanguage, TQT_SIGNAL( toggled( bool ) ), m_languageItem, TQT_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkBold, TQ_SIGNAL( toggled( bool ) ), m_boldYes, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkItalic, TQ_SIGNAL( toggled( bool ) ), m_italicYes, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkStrikeOut, TQ_SIGNAL( toggled( bool ) ), m_strikeOutItem, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkShadow, TQ_SIGNAL( toggled( bool ) ), m_shadowYes, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkWordByWord, TQ_SIGNAL( toggled( bool ) ), m_wordByWordYes, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkFontAttribute, TQ_SIGNAL( toggled( bool ) ), m_fontAttributeItem, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkLanguage, TQ_SIGNAL( toggled( bool ) ), m_languageItem, TQ_SLOT( setEnabled( bool ) ) );
 
 
-    TQObject::connect( m_checkBold, TQT_SIGNAL( toggled( bool ) ), m_boldNo, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkItalic, TQT_SIGNAL( toggled( bool ) ), m_italicNo, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkShadow, TQT_SIGNAL( toggled( bool ) ), m_shadowNo, TQT_SLOT( setEnabled( bool ) ) );
-    TQObject::connect( m_checkWordByWord, TQT_SIGNAL( toggled( bool ) ), m_wordByWordNo, TQT_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkBold, TQ_SIGNAL( toggled( bool ) ), m_boldNo, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkItalic, TQ_SIGNAL( toggled( bool ) ), m_italicNo, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkShadow, TQ_SIGNAL( toggled( bool ) ), m_shadowNo, TQ_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkWordByWord, TQ_SIGNAL( toggled( bool ) ), m_wordByWordNo, TQ_SLOT( setEnabled( bool ) ) );
 
 
-    TQObject::connect( m_checkVertAlign, TQT_SIGNAL( toggled( bool ) ), m_vertAlignItem, TQT_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkVertAlign, TQ_SIGNAL( toggled( bool ) ), m_vertAlignItem, TQ_SLOT( setEnabled( bool ) ) );
 
-    TQObject::connect( m_checkUnderline, TQT_SIGNAL( toggled( bool ) ), m_underlineItem, TQT_SLOT( setEnabled( bool ) ) );
+    TQObject::connect( m_checkUnderline, TQ_SIGNAL( toggled( bool ) ), m_underlineItem, TQ_SLOT( setEnabled( bool ) ) );
 
     slotReset();
 }
