@@ -149,32 +149,32 @@ void KoStyleManager::setupWidget(const KoStyleCollection& styleCollection)
 
     m_moveUpButton = new TQPushButton( frame1, "moveUpButton" );
     m_moveUpButton->setIconSet( SmallIconSet( "go-up" ) );
-    connect( m_moveUpButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveUpStyle() ) );
+    connect( m_moveUpButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( moveUpStyle() ) );
     frame1Layout->addWidget( m_moveUpButton, 1, 1 );
 
     m_moveDownButton = new TQPushButton( frame1, "moveDownButton" );
     m_moveDownButton->setIconSet( SmallIconSet( "go-down" ) );
-    connect( m_moveDownButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveDownStyle() ) );
+    connect( m_moveDownButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( moveDownStyle() ) );
     frame1Layout->addWidget( m_moveDownButton, 1, 0 );
 
 
     m_deleteButton = new TQPushButton( frame1, "deleteButton" );
     m_deleteButton->setText( i18n( "&Delete" ) );
-    connect( m_deleteButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( deleteStyle() ) );
+    connect( m_deleteButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( deleteStyle() ) );
 
     frame1Layout->addWidget( m_deleteButton, 2, 1 );
 
     m_newButton = new TQPushButton( frame1, "newButton" );
     m_newButton->setText( i18n( "New" ) );
-    connect( m_newButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( addStyle() ) );
+    connect( m_newButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addStyle() ) );
 
     frame1Layout->addWidget( m_newButton, 2, 0 );
 
     m_tabs = new TQTabWidget( frame1 );
     frame1Layout->addMultiCellWidget( m_tabs, 0, 2, 2, 2 );
 
-    connect( m_stylesList, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( switchStyle() ) );
-    connect( m_tabs, TQT_SIGNAL( currentChanged ( TQWidget * ) ), this, TQT_SLOT( switchTabs() ) );
+    connect( m_stylesList, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( switchStyle() ) );
+    connect( m_tabs, TQ_SIGNAL( currentChanged ( TQWidget * ) ), this, TQ_SLOT( switchTabs() ) );
 }
 
 void KoStyleManager::addGeneralTab( int flags ) {
@@ -186,7 +186,7 @@ void KoStyleManager::addGeneralTab( int flags ) {
 
     m_nameString = new TQLineEdit( tab );
     m_nameString->resize(m_nameString->sizeHint() );
-    connect( m_nameString, TQT_SIGNAL( textChanged( const TQString &) ), this, TQT_SLOT( renameStyle(const TQString &) ) );
+    connect( m_nameString, TQ_SIGNAL( textChanged( const TQString &) ), this, TQ_SLOT( renameStyle(const TQString &) ) );
 
     tabLayout->addWidget( m_nameString, 0, 1 );
 
