@@ -265,7 +265,7 @@ void KOfficePlugin::getEditingTime(KFileMetaInfoGroup group1,
 void KOfficePlugin::getDateTime(KFileMetaInfoGroup group1,
 		                const char * labelid, TQString & txt)
 {
-	TQDateTime dt = TQDateTime::fromString( txt, Qt::ISODate);
+	TQDateTime dt = TQDateTime::fromString( txt, TQt::ISODate);
 	appendItem( group1, labelid, dt);
 }
 
